************SAS CODE FOR RUG-III VERSION 5.20******************************* ;
*                                                                            ;
* Notice: These materials are in the public domain and cannot be copyrighted ;
* Last change:  08/02/05                                                     ;
*                                                                            ;
**************************DOCUMENTATION************************************* ;
*--------------------------------------------------------------------------- ;
* General documentation about the RUG-III Version 5.20 Grouper is provided   ;
*   in the document "Grouper Doc.pdf" in the grouper package.                ;
* User documentation for using the current SAS module (RUG520.SAS) is        ;
*   provided in the document "SAS Doc.pdf" in the grouper package.           ;  
*--------------------------------------------------------------------------- ;
*SYNTAX USED IN THIS  SAS  CODE:                                             ;
*                                                                            ;
*   1.  All lines with an asterisk (*) as the first nonblank character in    ;
*         the line are documentation or comment lines.  All command lines    ;
*         start with a character other than an asterisk.                     ;
*   2.  A semicolon indicates the end of a statement in the SAS code used    ;
*         here.                                                              ;
*   3.  All variables are represented in small letters, while command        ;
*         words are represented in capital letters.                          ;
*   4.  All MDS 2.0 variables are represented in small letters with names as ;
*         specified in the Uniform Data Submission Specifications for the    ;
*         MDS 2.0.  ALL MDS 2.0 VARIABLES ARE REQUIRED TO BE CHARACTER       ;
*         VARIABLES IN THIS SAS CODE.  The MDS 2.0 variable names            ;
*         correspond to the labels on the MDS 2.0 form.                      ;
*   5.  The RUG-III Grouper Version 5.20 input and output parameters use the ;
*         standard names found in "Grouper Doc.pdf" (also listed below)      ;
*   6.  All local (non-MDS) variables are represented in small and a prefix  ;
*         of "n_" is used for local numeric variables (e.g., n_reh_u).       ;
*   7.  The only command words and structures used in this SAS code are:     ;
*         a. IF <logical condition1>                                         ;
*              THEN <arithmetic statement> executed if condition1 true       ;
*            ELSE IF <logical condition2>                                    ;
*              THEN <arithmetic statement> executed if condition2 true       ;
*                DO <multiple statements>  END                               ;
*            ELSE   <arithmetic statement> executed if no condition is true  ;
*         b. Logical operators used in logical conditions are                ;
*                =       (equal)                                             ;
*                >       (greater than)                                      ;
*                <       (less than)                                         ;
*                >=      (greater than or equal to)                          ;
*                <=      (less than or equal to)                             ;
*                NE      (not equal to)                                      ;
*                NOT =   (not equal to)                                      ;
*         c. Relational operators used in logical conditions are             ;
*                 AND    (logical and)                                       ;
*                 NOT    (logical not)                                       ;
*                 OR     (logical or)                                        ;
*         d. INPUT(c_var,#.) -- the input function used with a numeric format;
*                 returns the numeric value for a character variable (c_var).;
*         e. GO TO <labeled statement> -- execution jumps to the <labeled    ;
*                 statement>. A labeled statement is a name followed by a    ;
*                 colon (:).  The only labeled statement in this code is     ;
*                 SKIPEND:.                                                  ;
*   8.  Nested IF structures are indented for clarity.                       ;
*   9.  Single quotes (') delimit a character constant.                      ;
*--------------------------------------------------------------------------- ;
*PRE-PROCESSING REQUIRED BEFORE EXECUTION OF RUG520.SAS:                     ;
*   1.  Read MDS 2.0 record text string (sMdsRecord) and create a SAS data   ;
*          set with appropriate character variables for the MDS 2.0 RUG-III  ;
*          variables listed in Section 8 of "Grouper Doc.pdf".  The grouper  ;
*          package includes an example SAS program (Read_MDS.SAS) a text     ;
*          string MDS file into a SAS data set.  Include item both AA8a and  ;
*          rec_id (first 2 bytes of sMdsRecord) in the SAS data set.  These  ;
*          two items are used in the present code.                           ;
*   2.  Set all grouper input parameters in Section 6 of "Grouper Doc.pdf"   ;
*   3.  Read a record from the SAS data set created in step #1 and process   ;
*          with RUG520.SAS.                                                  ;
*--------------------------------------------------------------------------- ;
*HANDLING OF OUT-OF-RANGE VALUES FOR MDS 2.0 ITEMS:                          ;
*In Step I of this SAS code, all 108 MDS 2.0 RUG-III items are scanned for   ;
*  valid ranges using the ranges given in Section 8 of "Grouper Doc.pdf". The;
*  RUG-III standard for range checking is to completely skip the             ;
*  classification logic and assign a default classification (Group BC1)if ANY;
*  one of the 108 MDS 2.0 items is out-of-range for a record.                ;
*Note that a standard CMS quarterly assessment is a partial 2 page           ;
*  assessment which does not include several of the items that are used for  ;
*  RUG-III classification.  If an MDS quarterly assessment record is the     ;
*  standard CMS partial quarterly, then that assessment will always result   ;
*  in a default classification (BC1) unless the additional, required RUG-III ;
*  items have been added to the record.  RUG-III classification requires that;
*  all 108 items be available.                                               ;
*Researchers may be interested in a best guess RUG-III classification even   ;
*  when missing (out-of-range) values are present.  The present code         ;
*  can be used for those purposes in the following manner:                   ;
*    1) For all variables other than aa8b, recode out of range values to a   ;
*       dash for single character variables or a dash-filled value for       ;
*       multi-character variables.                                           ;
*    2) For aa8b, recode an out of range value to a blank.                   ; 
*    3) Then execute the logic given in the present SAS code.                ;
*--------------------------------------------------------------------------- ;
*INPUT PARAMETERS USED IN THE CLASSIFICATION LOGIC:                          ;
*The input parameters must be set using the general grouper parameter names  ;
*  in Section 6 of "Grouper Doc.pdf".  See that section for a complete       ;
*  description of the input parameters.  The input parameters to this routine;
*  are:                                                                      ;
*   INPUT PARAMETER    TYPE                                                  ;
*   ---------------    -----                                                 ;
*   sRehabType         Character                                             ;
*   sModel             Character                                             ;
*   iQuarterlyFlag     Integer                                               ;
*   nCmiArray          Numeric array (58 elements)                           ;
*--------------------------------------------------------------------------- ;
*RESULT PARAMETERS PRODUCED BY THE CLASSIFICATION LOGIC:                     ;
*The output parameters are those listed in Section 6 of "Grouper Doc.pdf".   ;
*  See that section for a complete description of the input parameters.  The ;
*  output parameters from this routine are:                                  ;
*   OUTPUT PARAMETER   TYPE                                                  ;
*   ---------------    -----                                                 ;
*   sRugHier           Character                                             ;
*   sRugMax            Character                                             ;
*   nRugHier           Integer                                               ;
*   nRugMax            Integer                                               ;
*   nCmiValueHier      Numeric with decimals                                 ;
*   nCmiValueMax       Numeric with decimals                                 ;
*   iAdlSum            Integer                                               ;
*   iCpsCode           Integer                                              ;
*   sRUGsVersion       Character                                            ;
*   sDllVersion        Character                                            ;
*   iError             Integer                                              ;
*---------------------------------------------------------------------------
*INTERMEDIATE VARIABLES CREATED FOR USE IN THE CLASSIFICATION LOGIC:        ;

*Numeric Indicators for qualification in RUG-III clinical categories.  *    ;
*  For each of these indicators a 0 (zero) indicates not qualified     *    ;
*  and a 1 indicates qualified for the category.                       *    ;
*      n_reh_u   - ultra high rehabilitation                           *    ;
*      n_reh_v   - very high rehabilitation                            *    ;
*      n_reh_h   - high rehabilitation                                 *    ;
*      n_reh_m   - medium rehabilitation                               *    ;
*      n_reh_l   - low rehabilitation                                  *    ;
*      n_ext     - extensive care                                      *    ;
*      n_spec    - special care                                        *    ;
*      n_clin    - clinically complex                                  *    ;
*      n_impair  - impaired cognition                                  *    ;
*      n_behav   - behavior problems                                   *    ;
*                                                                      *    ;
*Other variables used in computations:                                 *    ;
*      n_bedmb  - numeric recode of bed mobility ADL                   *    ;
*      n_trans  - numeric recode of transfer ADL                       *    ;
*      n_toilt  - numeric recode of toileting ADL                      *    ;
*      n_intake - numeric indicator for parenteral/enteral intake level*    ;
*      n_eatng  - numeric recode of eating ADL                         *    ;
*      iAdlSum  - RUG-III ADL Index (numeric value between 4 and 18)   *    ;
*      n_th_min - minutes of rehab therapies totaled across therapies  *    ;
*      n_th_ty3 - number of types of rehab therapies received 3+ days  *    ;
*                    each                                              *    ;
*      n_th_ty5 - number of types of rehab therapies received 5+ days  *    ;
*                    each                                              *    ;
*      n_th_day - number of days of rehab therapies totaled across     *    ;
*                    therapies                                         *    ;
*      n_nrsum6 - number of nursing rehabilitation types on 6+ days    *    ;
*                    each                                              *    ;
*      n_nrsum2 - number of nursing rehabilitation types on 2+ days    *    ;
*                    each                                              *    ;
*      n_t1c    - numeric value of expected days of rehab therapy      *    ;
*      n_t1d    - numeric value of expected minutes of rehab therapy   *    ;
*      n_ulcer  - numeric count of number of ulcers, all levels        *    ;
*      n_sk_tr  - numeric count of selected skin treatments            *    ;
*      n_n_awak - numeric count of periods that the resident is not    *    ;
*                 awake                                                *    ;
*      n_p7     - numerical version of p7 (MD visits) for ease of      *    ;
*                 coding                                               *    ;
*      n_p8     - numerical value of p8 (MD orders) for ease of        *    ;
*                 coding                                               *    ;
*      n_mood   - numeric count of mood indicators                     *    ;
*      n_depres - numeric indicator of depression                      *    ;
*      n_coma   - numeric indicator of coma with selected qualifiers   *    ;
*      n_cog1   - numeric count of selected cognitive problems for     *    ;
*                 Cognitive Performance Scale                          *    ;
*      n_cog2   - second numeric count of selected cognitive problems  *    ;
*                 for Cognitive Performance Scale                      *    ;
*      iCpsCode - numeric Cognitive Performance Scale code             *    ;
*      n_ext_ct - count of number of selected hierarchy categories     *    ;
*                 for which resident qualifies and selected extensive  *    ;
*                 services (used in Extensive Services classification) *    ;
*      n_no     - value 1 signals problem found and should skip        *    ;
*                 classification                                       *    ;
************************************************************************    ;
*CODE ORGANIZATION:                                                         ;

*Version 5.12 employs a 2 stage process involving a clinical qualification   ;
*  stage followed by a classification stage as follows:                      ;
*      1.  Clinical Qualification Stage.  Determine all of RUG-III clinical  ;
*          categories (Extensive/Ultra High Rehab, Extensive/Very High Rehab,:
*          Extensive/High Rehab, Extensive/Medium Rehab,                     ;
*          Extensive/Low Rehab, Ultra High Rehab, Very High Rehab,           ;
*          High Rehab, Medium Rehab, Low Rehab, Extensive Services,          ;
*          Special Care, Clinically Complex, Cognitive Impairment, and       ;
*          Behavior Problems) for which a resident qualifies.  This first    ;
*          stage involves Step II through Step X in the code below.          ;
*      2.  Classification Stage. Scan all of the qualifications for a        ;
*          resident and classify the resident into a single clinical         ;
*          category using an hierarchical or index maximizing methodology    ;
*          and then classify the resident into one of the RUG-III groups     ;
*          contained in that clinical category.  This second stage involves  ;
*          Step XI in the code.                                              ;

*RUG-III 5.20 classifies a resident into the Extensive Services groups       ;
*  based on consideration of not only qualification for the Extensive        ;
*  Services clinical category, but also qualification for the Special        ;
*  Care, Clinically Complex, and Cognitive Impairment Clinical categories.   ;
*  This feature necessitates the two stage process.                          ;
*                                                                            ;
*RUG-III 5.20 classifies a resident into the Extensive & Rehabilitation      ;
*  groups based on consideration of not only qualification for               ;
*  Rehabilitation groups but also the Extensive Services groups.  This       ;
*  feature also necessitates the two stage process.                          ;

************************************************************************     ;
*RUG-III VERSION 5.20 HISTORY:                                               ;
*   SAS Code           08/02/95 by BG  initial version                      ;
************************************************************************     ;

**************************END OF DOCUMENTATION****************************** ;
*************************BEGINNING OF SAS CODE****************************** ;

*++++++++++++++++++++++++++++++++++++++++                                    ;
*Step I.  Initialize variables, check parameters, and perform range checks.  ;
*++++++++++++++++++++++++++++++++++++++++                                    ;

*Initialize outputs                                                          ;
sRugHier = 'BC1';
sRugMax = 'BC1';
nRugHier = 58;
nRugMax = 58;
iAdlSum = 0;
iCpsCode = 0;
sRugsVersion = '  ';
sDllVersion = '1.00';
iError = 0;
*Initialize output CMI variables to large negative number for hierarchical   ;
*   result group and index maximized result group                            ;
*nCmiValueHier is the CMI for the resulting hierarchical group               ;
nCmiValueHier = -9999; 
*nCmiValueMax is the CMI for the resulting index maximized group.            ;
nCmiValueMax = -9999;
*NOTE:  In this code, a initial value of 9999 for nCmiValueMax is used to   ;
*   indicate that neither index maximizing nor hierarchical classification   ;
*   has been made yet                                                        ; 

*Check for parameter errors and quit if appropriate                          ;
sRehabType = UPCASE(sRehabType);
IF sRehabType NOT = 'MCARE' AND sRehabType NOT = 'OTHER' THEN 
   DO;
      iError = 1;
      GO TO SKIPEND;
   END;
IF sModel NOT = '34' AND sModel NOT = '44' AND sModel NOT = '53' THEN 
   DO;
      iError = 2;
      GO TO SKIPEND;
   END;
IF iQuarterlyFlag NOT = 0 AND iQuarterlyFlag NOT = 1 THEN 
   DO;
      iError = 3;
      GO TO SKIPEND;
   END;

*Check if data or modification record and quit if not                        ;
IF rec_id NOT = 'B0' AND rec_id NOT = 'M0' THEN 
   DO;
      iError = 4;
      GO TO SKIPEND;
   END;

*Check type of assessment.  Initialize n_no to 1 and reset to 0 if           ;
*  appropriate type of assessment for classification                         ;
n_no = 1;
*Process full assessment                                                     ;
IF aa8a = '01' OR aa8a = '02' OR aa8a = '03' Or aa8a = '04' THEN
         n_no = 0;
*Process quarterly assessment if QuarterlyFlag = 1 (request to process       ;
*  quarterlies);
ELSE IF (aa8a = '05' OR aa8a = '10') AND iQuarterlyFlag = 1 THEN
         n_no = 0;
*Process PPS assessment                                                      ;
ELSE IF aa8b = '1' OR aa8b = '2' OR aa8b = '3' OR aa8b = '4' OR aa8b = '5' 
   OR aa8b = '7' OR aa8b = '8' THEN
         n_no = 0;
*Process other state-required assessment                                     ;
ELSE IF aa8a = '00' AND aa8b = '6' THEN
         n_no = 0;
*Process other assessment                                                    ;
ELSE IF aa8a = '00' AND aa8b = ' ' THEN
         n_no = 0;

*Quit if inappropriate assessment                                            ;
IF n_no = 1 THEN 
   DO;
      iError = 4;
      GO TO SKIPEND;
   END;

*Check CMI array for invalid values and quit if invalid value found          ;
n_no = 0;
DO i = 1 to 58;
   IF nCmiArray(i) <= -9999 THEN n_no = 1;
END;
IF n_no = 1 THEN 
   DO;
      iError = 5;
      GO TO SKIPEND;
   END;

*Set RUG-III version code based on model                                     ;
IF sModel = '34' THEN sRugsVersion = '08';
ELSE IF sModel = '44' THEN sRugsVersion = '07';
ELSE IF sModel = '53' THEN sRugsVersion = '09';

*Initialize intermediate variables                                           ;
n_reh_u  = 0;
n_reh_v  = 0;
n_reh_h  = 0;
n_reh_m  = 0;
n_reh_l  = 0;
n_ext    = 0;
n_spec   = 0;
n_clin   = 0;
n_impair = 0;
n_behav  = 0;
n_th_min = 0;
n_th_ty3 = 0;
n_th_ty5 = 0;
n_th_day = 0;
n_nrsum6 = 0;
n_nrsum2 = 0;
n_depres = 0;
n_ext_ct = 0;


*Initialize n_No, the number of out-of-range values found.                   ;
n_no = 0;

*Perform range checks on RUG-III variables.                                  ;
IF NOT (aa8b = ' ') THEN DO;
   IF aa8b < '1' OR aa8b > '8' THEN n_no = n_no + 1;
END;
IF NOT (b1 = '-') THEN DO;
   IF b1   < '0' OR b1   > '1' THEN n_no = n_no + 1;
END;
IF NOT (b2a = '-' OR b2a = ' ') THEN DO;
   IF b2a   < '0' OR b2a   > '1' THEN n_no = n_no + 1;
END;
IF NOT (b4 = '-' OR b4 = ' ') THEN DO;
   IF b4   < '0' OR b4   > '3' THEN n_no = n_no + 1;
END;
IF NOT (c4 = '-' OR c4 = ' ') THEN DO;
   IF c4   < '0' OR c4   > '3' THEN n_no = n_no + 1;
END;
IF NOT (e1a = '-' OR e1a = ' ') THEN DO;
   IF e1a   < '0' OR e1a   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1b = '-' OR e1b = ' ') THEN DO;
   IF e1b   < '0' OR e1b   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1c = '-' OR e1c = ' ') THEN DO;
   IF e1c   < '0' OR e1c   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1d = '-' OR e1d = ' ') THEN DO;
   IF e1d   < '0' OR e1d   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1e = '-' OR e1e = ' ') THEN DO;
   IF e1e   < '0' OR e1e   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1f = '-' OR e1f = ' ') THEN DO;
   IF e1f   < '0' OR e1f   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1g = '-' OR e1g = ' ') THEN DO;
   IF e1g   < '0' OR e1g   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1h = '-' OR e1h = ' ') THEN DO;
   IF e1h   < '0' OR e1h   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1i = '-' OR e1i = ' ') THEN DO;
   IF e1i   < '0' OR e1i   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1j = '-' OR e1j = ' ') THEN DO;
   IF e1j   < '0' OR e1j   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1k = '-' OR e1k = ' ') THEN DO;
   IF e1k   < '0' OR e1k   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1l = '-' OR e1l = ' ') THEN DO;
   IF e1l   < '0' OR e1l   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1m = '-' OR e1m = ' ') THEN DO;
   IF e1m   < '0' OR e1m   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1n = '-' OR e1n = ' ') THEN DO;
   IF e1n   < '0' OR e1n   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1o = '-' OR e1o = ' ') THEN DO;
   IF e1o   < '0' OR e1o   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e1p = '-' OR e1p = ' ') THEN DO;
   IF e1p   < '0' OR e1p   > '2' THEN n_no = n_no + 1;
END;
IF NOT (e4aa = '-' OR e4aa = ' ') THEN DO;
   IF e4aa   < '0' OR e4aa   > '3' THEN n_no = n_no + 1;
END;
IF NOT (e4ba = '-' OR e4ba = ' ') THEN DO;
   IF e4ba   < '0' OR e4ba   > '3' THEN n_no = n_no + 1;
END;
IF NOT (e4ca = '-' OR e4ca = ' ') THEN DO;
   IF e4ca   < '0' OR e4ca   > '3' THEN n_no = n_no + 1;
END;
IF NOT (e4da = '-' OR e4da = ' ') THEN DO;
   IF e4da   < '0' OR e4da   > '3' THEN n_no = n_no + 1;
END;
IF NOT (e4ea = '-' OR e4ea = ' ') THEN DO;
   IF e4ea   < '0' OR e4ea   > '3' THEN n_no = n_no + 1;
END;
IF NOT (g1aa = '-' OR g1aa = '8') THEN DO;
   IF g1aa   < '0' OR g1aa   > '4' THEN n_no = n_no + 1;
END;
IF NOT (g1ab = '-' OR g1ab = '8') THEN DO;
   IF g1ab   < '0' OR g1ab   > '3' THEN n_no = n_no + 1;
END;
IF NOT (g1ba = '-' OR g1ba = '8') THEN DO;
   IF g1ba   < '0' OR g1ba   > '4' THEN n_no = n_no + 1;
END;
IF NOT (g1bb = '-' OR g1bb = '8') THEN DO;
   IF g1bb   < '0' OR g1bb   > '3' THEN n_no = n_no + 1;
END;
IF NOT (g1ha = '-' OR g1ha = '8') THEN DO;
   IF g1ha   < '0' OR g1ha   > '4' THEN n_no = n_no + 1;
END;
IF NOT (g1ia = '-' OR g1ia = '8') THEN DO;
   IF g1ia   < '0' OR g1ia   > '4' THEN n_no = n_no + 1;
END;
IF NOT (g1ib = '-' OR g1ib = '8') THEN DO;
   IF g1ib   < '0' OR g1ib   > '3' THEN n_no = n_no + 1;
END;
IF NOT (h3a = '-') THEN DO;
   IF h3a   < '0' OR h3a   > '1' THEN n_no = n_no + 1;
END;
IF NOT (h3b = '-') THEN DO;
   IF h3b   < '0' OR h3b   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i1a = '-') THEN DO;
   IF i1a   < '0' OR i1a   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i1r = '-') THEN DO;
   IF i1r   < '0' OR i1r   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i1s = '-') THEN DO;
   IF i1s   < '0' OR i1s   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i1v = '-') THEN DO;
   IF i1v   < '0' OR i1v   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i1w = '-') THEN DO;
   IF i1w   < '0' OR i1w   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i1z = '-') THEN DO;
   IF i1z   < '0' OR i1z   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i2e = '-') THEN DO;
   IF i2e   < '0' OR i2e   > '1' THEN n_no = n_no + 1;
END;
IF NOT (i2g = '-') THEN DO;
   IF i2g   < '0' OR i2g   > '1' THEN n_no = n_no + 1;
END;
IF NOT (j1c = '-') THEN DO;
   IF j1c   < '0' OR j1c   > '1' THEN n_no = n_no + 1;
END;
IF NOT (j1e = '-') THEN DO;
   IF j1e   < '0' OR j1e   > '1' THEN n_no = n_no + 1;
END;
IF NOT (j1h = '-') THEN DO;
   IF j1h   < '0' OR j1h   > '1' THEN n_no = n_no + 1;
END;
IF NOT (j1i = '-') THEN DO;
   IF j1i   < '0' OR j1i   > '1' THEN n_no = n_no + 1;
END;
IF NOT (j1j = '-') THEN DO;
   IF j1j   < '0' OR j1j   > '1' THEN n_no = n_no + 1;
END;
IF NOT (j1o = '-') THEN DO;
   IF j1o   < '0' OR j1o   > '1' THEN n_no = n_no + 1;
END;
IF NOT (k3a = '-') THEN DO;
   IF k3a   < '0' OR k3a   > '1' THEN n_no = n_no + 1;
END;
IF NOT (k5a = '-') THEN DO;
   IF k5a   < '0' OR k5a   > '1' THEN n_no = n_no + 1;
END;
IF NOT (k5b = '-') THEN DO;
   IF k5b   < '0' OR k5b   > '1' THEN n_no = n_no + 1;
END;
IF NOT (k6a = '-' OR k6a = ' ') THEN DO;
   IF k6a   < '0' OR k6a   > '4' THEN n_no = n_no + 1;
END;
IF NOT (k6b = '-' OR k6b = ' ') THEN DO;
   IF k6b   < '0' OR k6b   > '5' THEN n_no = n_no + 1;
END;
IF NOT (m1a = '-') THEN DO;
   IF m1a   < '0' OR m1a   > '9' THEN n_no = n_no + 1;
END;
IF NOT (m1b = '-') THEN DO;
   IF m1b   < '0' OR m1b   > '9' THEN n_no = n_no + 1;
END;
IF NOT (m1c = '-') THEN DO;
   IF m1c   < '0' OR m1c   > '9' THEN n_no = n_no + 1;
END;
IF NOT (m1d = '-') THEN DO;
   IF m1d   < '0' OR m1d   > '9' THEN n_no = n_no + 1;
END;
IF NOT (m2a = '-') THEN DO;
   IF m2a   < '0' OR m2a   > '4' THEN n_no = n_no + 1;
END;
IF NOT (m4b = '-') THEN DO;
   IF m4b   < '0' OR m4b   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m4c = '-') THEN DO;
   IF m4c   < '0' OR m4c   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m4g = '-') THEN DO;
   IF m4g   < '0' OR m4g   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5a = '-') THEN DO;
   IF m5a   < '0' OR m5a   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5b = '-') THEN DO;
   IF m5b   < '0' OR m5b   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5c = '-') THEN DO;
   IF m5c   < '0' OR m5c   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5d = '-') THEN DO;
   IF m5d   < '0' OR m5d   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5e = '-') THEN DO;
   IF m5e   < '0' OR m5e   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5f = '-') THEN DO;
   IF m5f   < '0' OR m5f   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5g = '-') THEN DO;
   IF m5g   < '0' OR m5g   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m5h = '-') THEN DO;
   IF m5h   < '0' OR m5h   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m6b = '-') THEN DO;
   IF m6b   < '0' OR m6b   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m6c = '-') THEN DO;
   IF m6c   < '0' OR m6c   > '1' THEN n_no = n_no + 1;
END;
IF NOT (m6f = '-') THEN DO;
   IF m6f   < '0' OR m6f   > '1' THEN n_no = n_no + 1;
END;
IF NOT (n1a = '-') THEN DO;
   IF n1a   < '0' OR n1a   > '1' THEN n_no = n_no + 1;
END;
IF NOT (n1b = '-') THEN DO;
   IF n1b   < '0' OR n1b   > '1' THEN n_no = n_no + 1;
END;
IF NOT (n1c = '-') THEN DO;
   IF n1c   < '0' OR n1c   > '1' THEN n_no = n_no + 1;
END;
IF NOT (o3 = '-') THEN DO;
   IF o3   < '0' OR o3   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p1aa = '-') THEN DO;
   IF p1aa   < '0' OR p1aa   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1ab = '-') THEN DO;
   IF p1ab   < '0' OR p1ab   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1ac = '-') THEN DO;
   IF p1ac   < '0' OR p1ac   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1ag = '-') THEN DO;
   IF p1ag   < '0' OR p1ag   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1ah = '-') THEN DO;
   IF p1ah   < '0' OR p1ah   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1ai = '-') THEN DO;
   IF p1ai   < '0' OR p1ai   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1aj = '-') THEN DO;
   IF p1aj   < '0' OR p1aj   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1ak = '-') THEN DO;
   IF p1ak   < '0' OR p1ak   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1al = '-') THEN DO;
   IF p1al   < '0' OR p1al   > '1' THEN n_no = n_no + 1;
END;
IF NOT (p1baa = '-') THEN DO;
   IF p1baa   < '0' OR p1baa   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p1bab = '----') THEN DO;
   IF      SUBSTR(p1bab,1,1) < '0' OR SUBSTR(p1bab,1,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bab,2,1) < '0' OR SUBSTR(p1bab,2,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bab,3,1) < '0' OR SUBSTR(p1bab,3,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bab,4,1) < '0' OR SUBSTR(p1bab,4,1) > '9'
         THEN n_no = n_no + 1;
END;
IF NOT (p1bba = '-') THEN DO;
   IF p1bba   < '0' OR p1bba   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p1bbb = '----') THEN DO;
   IF      SUBSTR(p1bbb,1,1) < '0' OR SUBSTR(p1bbb,1,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bbb,2,1) < '0' OR SUBSTR(p1bbb,2,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bbb,3,1) < '0' OR SUBSTR(p1bbb,3,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bbb,4,1) < '0' OR SUBSTR(p1bbb,4,1) > '9'
         THEN n_no = n_no + 1;
END;
IF NOT (p1bca = '-') THEN DO;
   IF p1bca   < '0' OR p1bca   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p1bcb = '----') THEN DO;
   IF      SUBSTR(p1bcb,1,1) < '0' OR SUBSTR(p1bcb,1,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bcb,2,1) < '0' OR SUBSTR(p1bcb,2,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bcb,3,1) < '0' OR SUBSTR(p1bcb,3,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p1bcb,4,1) < '0' OR SUBSTR(p1bcb,4,1) > '9'
         THEN n_no = n_no + 1;
END;
IF NOT (p1bda = '-') THEN DO;
   IF p1bda   < '0' OR p1bda   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3a = '-') THEN DO;
   IF p3a   < '0' OR p3a   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3b = '-') THEN DO;
   IF p3b   < '0' OR p3b   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3c = '-') THEN DO;
   IF p3c   < '0' OR p3c   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3d = '-') THEN DO;
   IF p3d   < '0' OR p3d   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3e = '-') THEN DO;
   IF p3e   < '0' OR p3e   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3f = '-') THEN DO;
   IF p3f   < '0' OR p3f   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3g = '-') THEN DO;
   IF p3g   < '0' OR p3g   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3h = '-') THEN DO;
   IF p3h   < '0' OR p3h   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3i = '-') THEN DO;
   IF p3i   < '0' OR p3i   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p3j = '-') THEN DO;
   IF p3j   < '0' OR p3j   > '7' THEN n_no = n_no + 1;
END;
IF NOT (p7 = '--') THEN DO;
   IF      SUBSTR(p7,1,1) < '0' OR SUBSTR(p7,1,1) > '1'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p7,1,1) = '0' AND (SUBSTR(p7,2,1) < '0'
           OR SUBSTR(p7,2,1) > '9')
              THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p7,1,1) = '1' AND (SUBSTR(p7,2,1) < '0'
           OR SUBSTR(p7,2,1) > '4')
              THEN n_no = n_no + 1;
END;
IF NOT (p8 = '--') THEN DO;
   IF      SUBSTR(p8,1,1) < '0' OR SUBSTR(p8,1,1) > '1'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p8,1,1) = '0' AND (SUBSTR(p8,2,1) < '0'
           OR SUBSTR(p8,2,1) > '9')
              THEN n_no = n_no + 1;
   ELSE IF SUBSTR(p8,1,1) = '1' AND (SUBSTR(p8,2,1) < '0'
           OR SUBSTR(p8,2,1) > '4')
              THEN n_no = n_no + 1;
END;
IF NOT (t1b = '-' OR t1b = ' ') THEN DO;
   IF t1b   < '0' OR t1b   > '1' THEN n_no = n_no + 1;
END;
IF NOT (t1c = '--' OR t1c = '  ') THEN DO;
   IF      SUBSTR(t1c,1,1) < '0' OR SUBSTR(t1c,1,1) > '1'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(t1c,1,1) = '0' AND (SUBSTR(t1c,2,1) < '0'
           OR SUBSTR(t1c,2,1) > '9')
              THEN n_no = n_no + 1;
   ELSE IF SUBSTR(t1c,1,1) = '1' AND (SUBSTR(t1c,2,1) < '0'
           OR SUBSTR(t1c,2,1) > '5')
              THEN n_no = n_no + 1;
END;
IF NOT (t1d = '----' OR t1d = '    ') THEN DO;
   IF      SUBSTR(t1d,1,1) < '0' OR SUBSTR(t1d,1,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(t1d,2,1) < '0' OR SUBSTR(t1d,2,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(t1d,3,1) < '0' OR SUBSTR(t1d,3,1) > '9'
         THEN n_no = n_no + 1;
   ELSE IF SUBSTR(t1d,4,1) < '0' OR SUBSTR(t1d,4,1) > '9'
         THEN n_no = n_no + 1;
END;

*Classify only when all data is within range.                                ;
IF n_no NE 0 THEN GO TO SKIPEND;

*****************************************                                    ;
*Begin calculation.                     *                                    ;
*****************************************                                    ;

*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++  ;
*Step II. Calculate RUG-III ADL Index.                                       ;
*         The ADL index is required for use in splitting the Rehabilitation, ;
*            Special Care, Clinically Complex, Impaired Cognition, Behavior  ;
*            Problems, and Reduced Physical Function RUG-III clinical        ;
*            categories.  The ADL index requires scoring conversion for      ;
*            4 different ADL's and then summation.                           ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++  ;

*ADL scoring conversion for Bed mobility                                     ;
IF      (  g1aa = '-'  OR    g1aa = '0'  OR    g1aa = '1') THEN
              n_bedmb = 1;
ELSE IF (  g1aa =  '2')                                    THEN
              n_bedmb = 3;
ELSE IF (  g1aa = '3'  OR    g1aa = '4'  OR    g1aa = '8') THEN DO;
   IF     (  g1ab = '-'  OR    g1ab = '0'
            OR    g1ab = '1'   OR    g1ab =  '2')          THEN
              n_bedmb = 4;
   ELSE IF (  g1ab = '3'   OR    g1ab = '8')               THEN
              n_bedmb = 5;
   END;


*-------------------------------                                             ;
*ADL scoring conversion for Transfer                                         ;
IF     (  g1ba = '-'  OR    g1ba = '0'  OR    g1ba = '1')  THEN
              n_trans = 1;
ELSE IF (  g1ba =  '2')                                    THEN
              n_trans = 3;
ELSE IF (  g1ba = '3'  OR    g1ba = '4'  OR    g1ba = '8') THEN DO;
   IF     (  g1bb = '-'  OR    g1bb = '0'
            OR    g1bb = '1'  OR    g1bb =  '2')           THEN
              n_trans = 4;
   ELSE IF (  g1bb = '3'   OR    g1bb = '8')               THEN
              n_trans = 5;
   END;


*-------------------------------                                             ;
*ADL scoring conversion for Toilet Use                                       ;
IF     (  g1ia = '-'  OR    g1ia = '0'  OR    g1ia = '1')  THEN
              n_toilt = 1;
ELSE IF (  g1ia =  '2')                                    THEN
              n_toilt = 3;
ELSE IF (  g1ia = '3'  OR    g1ia = '4'  OR    g1ia = '8') THEN DO;
   IF     (  g1ib = '-'  OR    g1ib = '0'
            OR    g1ib = '1'  OR    g1ib =  '2')           THEN
              n_toilt = 4;
   ELSE IF (  g1ib = '3'   OR    g1ib = '8')               THEN
              n_toilt = 5;
   END;


*-------------------------------                                             ;
*Code parenteral\enteral intake level--used for Eating scoring conversion and;
*later for Special Care and Clinically Complex qualification.                ;
*   n_intake = 1 if (1) 51% or more of total calories are received           ;
*                through parenteral/enteral intake (k6a) or (2) 26% to 50%   ;
*                of total calories received through parenteral/enteral       ;
*                intake (k6a) and fluid intake is 501 or more cc per day     ;
*                (k6b).                                                      ;
*   n_intake = 0 if parenteral/enteral intake is at a lower level (including ;
*                none).                                                      ;
n_intake = 0;
IF      (  k6a = '3'  OR    k6a = '4')                                   THEN
           n_intake = 1;
ELSE IF (  k6a = '2')  AND
        (  k6b = '2'  OR    k6b = '3'  OR    k6b = '4'  OR    k6b = '5') THEN
           n_intake = 1;


*ADL scoring conversion for Eating                                           ;
IF     (  k5a = '1')  OR  (  k5b = '1'  AND  n_intake = 1) THEN
          n_eatng = 3;
ELSE IF (  g1ha = '-'  OR    g1ha = '0'  OR    g1ha = '1') THEN
          n_eatng = 1;
ELSE IF (  g1ha = '2')                                     THEN
          n_eatng = 2;
ELSE IF (  g1ha = '3'  OR    g1ha = '4'  OR    g1ha = '8') THEN
          n_eatng = 3;


*-------------------------------                                             ;
*Sum the converted ADL scores to iAdlSum                                     ;
   iAdlSum = n_bedmb + n_trans + n_toilt + n_eatng;

*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++       ;
*Step III. Determine Rehab and Rehab nursing variables needed for            ;
*            Rehab categories.                                               ;

*          Variables needed to determine Rehab clinical hierarchy            ;
*            qualification for Standard rehab classification:                ;
*             - Total minutes of rehab therapy received (n_th_min)           ;
*             - Total number of days of rehab received (n_th_day)            ;
*             - Number of types of rehab therapy (n_th_ty3) received         ;
*                  at 3+ days each                                           ;
*             - Number of types of rehab therapy (n_th_ty5) received         ;
*                  at 5+ days each                                           ;
*             - Number of types of nursing rehab activities (n_nrsum6) at    ;
*                  6+ days each  (Note that n_nrsum6 includes any            ;
*                  scheduled toileting plan or bladder retraining program    ;
*                  as a component.)                                          ;

*          Additional variable needed to determine Rehab clinical hierarchy  ;
*            qualification for Special Medicare rehab classification:        ;
*             - Number of types of nursing rehab activities (n_nrsum2) at    ;
*                  2+ days each  (Note that n_nrsum2 includes any            ;
*                  scheduled toileting plan or bladder retraining program    ;
*                  as a component.)                                          ;
*             - Numeric versions of expected days (t1c) and expected         ;
*                  minutes (t1d) of rehab therapy.                           ;
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++       ;

*-------------------------------                                             ;
*Determine n_th_min -- the number of minutes of rehab therapy received.      ;

n_th_min = 0;

*Add speech therapy minutes unless dash filled (value '----')                ;
IF (  p1bab NE '----')                THEN
   n_th_min = SUM(n_th_min,INPUT(compress(p1bab,'-'),4.));


*Add occupational therapy minutes unless dash filled (value '----')          ;
IF (  p1bbb NE '----')                THEN
   n_th_min = SUM(n_th_min,INPUT( compress( p1bbb,'-'),4.));


*Add physical therapy minutes unless dash filled (value '----')              ;
IF (  p1bcb NE '----')                THEN
   n_th_min = SUM(n_th_min,INPUT(  compress(p1bcb,'-'),4.));


*-------------------------------                                             ;
*Determine n_th_day -- the number of days of rehab therapy received.         ;

n_th_day = 0;

*Add speech therapy days if in valid numeric range                           ;
IF ('1' <=   p1baa  AND    p1baa <= '7')    THEN
   n_th_day = n_th_day + INPUT(  p1baa,1.);


*Add occupational therapy days if in valid numeric range                     ;
IF ('1' <=   p1bba  AND    p1bba <= '7')    THEN
   n_th_day = n_th_day + INPUT(  p1bba,1.);


*Add physical therapy days if in valid numeric range                         ;
IF ('1' <=   p1bca  AND    p1bca <= '7')    THEN
   n_th_day = n_th_day + INPUT(  p1bca,1.);


*-------------------------------                                             ;
*Determine n_th_ty3.                                                         ;
*   n_th_ty3 represents the number of different rehab therapies that         ;
*   were provided on 3 or more days during that period. It is used           ;
*   to determine qualification for Ultra High intensity rehab.               ;

n_th_ty3 = 0;
IF ('3' <=   p1baa  AND    p1baa <= '7')    THEN
   n_th_ty3 = n_th_ty3 + 1;

IF ('3' <=   p1bba  AND    p1bba <= '7')    THEN
   n_th_ty3 = n_th_ty3 + 1;

IF ('3' <=   p1bca  AND    p1bca <= '7')    THEN
   n_th_ty3 = n_th_ty3 + 1;


*-------------------------------                                             ;
*Determine n_th_ty5.                                                         ;
*   n_th_ty5 represents the number of different rehab therapies that         ;
*   were provided on 5 or more days during that period. It is used           ;
*   to determine qualification for Ultra High, Very High and High            ;
*   intensity rehab.                                                         ;

n_th_ty5 = 0;
IF ('5' <=   p1baa  AND    p1baa <= '7')    THEN
   n_th_ty5 = n_th_ty5 + 1;

IF ('5' <=   p1bba  AND    p1bba <= '7')    THEN
   n_th_ty5 = n_th_ty5 + 1;

IF ('5' <=   p1bca  AND    p1bca <= '7')    THEN
   n_th_ty5 = n_th_ty5 + 1;


*-------------------------------                                             ;
*Determine n_nrsum6.                                                         ;
*   n_nrsum6 is a count of the number of types of nursing rehab activities   ;
*   provided at least 6 days per week.  Note that a scheduled toileting      ;
*   plan or bladder retraining program is included in this count.            ;

n_nrsum6 = 0;

*Add 1 for passive range of motion (p3a) or active range of motion (p3b)     ;
IF (('6' <=   p3a  AND    p3a <= '7')  OR
    ('6' <=   p3b  AND    p3b <= '7'))      THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for bed mobility (p3d) or walking (p3f) training                      ;
IF (('6' <=   p3d  AND    p3d <= '7')  OR
    ('6' <=   p3f  AND    p3f <= '7'))      THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for splint or brace assistance (p3c)                                  ;
IF ('6' <=   p3c  AND    p3c <= '7')        THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for transfer training (p3e)                                           ;
IF ('6' <=   p3e  AND    p3e <= '7')        THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for dressing or grooming training (p3g)                               ;
IF ('6' <=   p3g  AND    p3g <= '7')        THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for eating or swallowing training (p3h)                               ;
IF ('6' <=   p3h  AND    p3h <= '7')        THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for amputation/prosthesis care (p3i)                                  ;
IF ('6' <=   p3i  AND    p3i <= '7')        THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for communication training (p3j)                                      ;
IF ('6' <=   p3j  AND    p3j <= '7')        THEN
   n_nrsum6 = n_nrsum6 + 1;


*Add 1 for any scheduled toileting plan (h3a) or bladder retraining          ;
*   program (h3b)                                                            ;
IF (  h3a = '1' OR   h3b = '1')             THEN
   n_nrsum6 = n_nrsum6 + 1;


*-------------------------------                                             ;
*Determine n_nrsum2.                                                         ;
*   n_nrsum2 is a count of the number of types of nursing rehab activities   ;
*   provided at least 2 days per week.  Note that a scheduled toileting      ;
*   plan or bladder retraining program is included in this count.            ;
n_nrsum2 = 0;

*Add 1 for passive range of motion (p3a) or active range of motion (p3b)     ;
IF (('2' <=   p3a  AND    p3a <= '7')  OR
    ('2' <=   p3b  AND    p3b <= '7'))      THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for bed mobility (p3d) or walking (p3f) training                      ;
IF (('2' <=   p3d  AND    p3d <= '7')  OR
    ('2' <=   p3f  AND    p3f <= '7'))      THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for splint or brace assistance (p3c)                                  ;
IF ('2' <=   p3c  AND    p3c <= '7')        THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for transfer training (p3e)                                           ;
IF ('2' <=   p3e  AND    p3e <= '7')        THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for dressing or grooming training (p3g)                               ;
IF ('2' <=   p3g  AND    p3g <= '7')        THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for eating or swallowing training (p3h)                               ;
IF ('2' <=   p3h  AND    p3h <= '7')        THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for amputation/prosthesis care (p3i)                                  ;
IF ('2' <=   p3i  AND    p3i <= '7')        THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for communication training (p3j)                                      ;
IF ('2' <=   p3j  AND    p3j <= '7')        THEN
   n_nrsum2 = n_nrsum2 + 1;


*Add 1 for any scheduled toileting plan (h3a) or bladder retraining          ;
*   program (h3b)                                                            ;
IF (  h3a = '1' OR   h3b = '1')           THEN
   n_nrsum2 = n_nrsum2 + 1;


*-------------------------------                                             ;
*Create n_t1c and n_t1d, numeric variables for expected days (t1c) and       ;
*   minutes (t1d) of rehab therapy.                                          ;

*Set value of n_t1c to 0 if t1c is blank or dash filled (value = '--').      ;
IF (  t1c = '  '  OR    t1c = '--')      THEN
   n_t1c = 0;
ELSE
   n_t1c = INPUT(  t1c,2.);


*Set value of n_t1d to 0 if t1dc is blank or dash filled (value = '----').   ;
IF (  t1d = '    '  OR    t1d = '----')  THEN
   n_t1d = 0;
ELSE
   n_t1d = INPUT(  t1d,4.);


*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
*Step IV. Test Rehab category qualification.                                 ;
*          Rehab categories are separated by several factors: Total minutes  ;
*          of rehab therapy, number of types of therapy, and number of types ;
*          of nursing rehab activities.                                      ;
*                                                                            ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

*-------------------------------                                             ;
*Determine qualification for Ultra High Rehab                                ;
        *-------------------------------                                     ;
        *Resident qualifies for Ultra High Intensity Rehab.                  ;
        *   Qualifications:                                                  ;
        *      (1) 720+ minutes received across all types (n_th_min)         ;
        *                AND                                                 ;
        *      (2) 5+ days received for 1 type of therapy (n_th_ty5)         ;
        *                AND                                                 ;
        *      (3) 3+ days received for a second type of                     ;
        *          therapy (n_th_ty3)                                        ;

IF (       n_th_min >= 720
       AND n_th_ty5 >= 1
       AND n_th_ty3 >= 2   )
  THEN
                     n_reh_u = 1;



*-------------------------------                                             ;
*Determine qualification for Very High Rehab                                 ;
        *-------------------------------                                     ;
        *Resident qualifies for Very High Intensity Rehab.                   ;
        *   Qualifications:                                                  ;
        *      (1) 500+ minutes received across all types (n_th_min)         ;
        *                AND                                                 ;
        *      (2) 5+ days received for 1 type of therapy (n_th_ty5)         ;

IF (       n_th_min >= 500
       AND n_th_ty5 >= 1  )
  THEN
                     n_reh_v = 1;



*-------------------------------                                             ;
*Determine qualification for High Rehab                                      ;
         *-------------------------------                                    ;
         *Resident qualifies for High Intensity Rehab.                       ;
         *      Qualifications:                                              ;
         *         (1) 325+ minutes received across all types (n_th_min)     ;
         *                   AND                                             ;
         *         (2) 5+ days received for 1 type of therapy (n_th_ty5)     ;
         *                                                                   ;
         *   If the resident does not meet these qualifications and          ;
         *   (1) the rehab qualification method is Medicare (i.e., the       ;
         *   parameter sRehabType = 'MCARE') and (2) the reason for          ;
         *   assessment involves a supplemental assessment type of           ;
         *   "5 day assessment" (AA8b = '1') OR "readmission assessment"     ;
         *   (AA8b = '5'), then the resident may qualify for High            ;
         *   Intensity Rehab under the following Special Medicare            ;
         *   Provisions.                                                     ;
         *      Qualifications under Special Medicare Provisions:            ;
         *         (1) Physician has ordered therapies (t1b)                 ;
         *                AND                                                ;
         *         (2) 65+ minutes received across all types (n_th_min)      ;
         *                AND                                                ;
         *         (3) 520+ minutes of expected therapy (t1d)                ;
         *                AND                                                ;
         *         (4) 8+ days of expected therapy (t1c)                     ;

IF (       n_th_min >= 325
       AND n_th_ty5 >= 1   )
  THEN
                     n_reh_h = 1;

ELSE IF ((  aa8b = '1' OR   aa8b = '5') AND sRehabType = 'MCARE') THEN DO;

   IF (         t1b = '1'
          AND n_th_min >= 65
          AND n_t1d >= 520
          AND (8 <= n_t1c AND n_t1c <= 15))
      THEN
                     n_reh_h = 1;

   END;



*-------------------------------                                             ;
*Determine qualification for Medium Rehab                                    ;
         *-------------------------------                                    ;
         *Resident qualifies for Medium Rehab.                               ;
         *      Qualifications:                                              ;
         *         (1) 150+ minutes received across all types (n_th_min)     ;
         *                AND                                                ;
         *         (2) 5+ days received across all types of                  ;
         *             therapy (n_th_day)                                    ;
         *                                                                   ;
         *   If the resident does not meet these qualifications and          ;
         *   (1) the rehab qualification method is Medicare (i.e., the       ;
         *   parameter sRehabType = 'MCARE') and (2) the reason for          ;
         *   assessment involves a supplemental assessment type of           ;
         *   "5 day assessment" (AA8b = '1') OR "readmission assessment"     ;
         *   (AA8b = '5'), then the resident may qualify for Medium          ;
         *   Intensity Rehab under the following Special Medicare            ;
         *   Provisions.                                                     ;
         *      Qualifications under Special Medicare Provisions:            ;
         *         (1) Physician has ordered therapies (t1b)                 ;
         *                AND                                                ;
         *         (2) 240+ minutes of expected therapy (t1d)                ;
         *                AND                                                ;
         *         (3) 8+ days of expected therapy (t1c)                     ;

IF (n_th_min >= 150 AND n_th_day >= 5)
  THEN
                     n_reh_m = 1;

ELSE IF ((  aa8b = '1' OR   aa8b = '5') AND sRehabType = 'MCARE') THEN DO;

   IF (  t1b = '1' AND n_t1d >= 240 AND
       (8 <= n_t1c AND n_t1c <= 15))
     THEN
                     n_reh_m = 1;

   END;



*-------------------------------                                             ;
*Determine qualification for Low Rehab                                       ;
         *-------------------------------                                    ;
         *Resident qualifies for Low Intensity Rehab.                        ;
         *      Qualifications:                                              ;
         *         (1) 45+ minutes received across all types (n_th_min)      ;
         *                AND                                                ;
         *         (2) 3+ days received across all types of                  ;
         *             therapy (n_th_day)                                    ;
         *                AND                                                ;
         *         (3) 2+ nursing rehab activities at 6+ days                ;
         *             each (n_nrsum6)                                       ;
         *                                                                   ;
         *   If the resident does not meet these qualifications and          ;
         *   (1) the rehab qualification method is Medicare (i.e., the       ;
         *   parameter sRehabType = 'MCARE') and (2) the reason for          ;
         *   assessment involves a supplemental assessment type of           ;
         *   "5 day assessment" (AA8b = '1') OR "readmission assessment"     ;
         *   (AA8b = '5'), then the resident may qualify for Low             ;
         *   Intensity Rehab under the following Special Medicare            ;
         *   Provisions.                                                     ;
         *      Qualifications under Special Medicare Provisions:            ;
         *         (1) Physician has ordered therapies (t1b)                 ;
         *                AND                                                ;
         *         (2) 75+ minutes of expected therapy (t1d)                 ;
         *                AND                                                ;
         *         (3) 5+ days of expected therapy (t1c)                     ;
         *         (4) 2+ nursing rehab activities at 2+ days                ;
         *             each (n_nrsum2)                                       ;

IF (n_th_min >= 45 AND n_th_day >= 3 AND n_nrsum6 >= 2)
  THEN
                     n_reh_l = 1;

ELSE IF ((  aa8b = '1' OR   aa8b = '5') AND sRehabType = 'MCARE') THEN DO;

   IF (  t1b = '1' AND n_t1d >= 75  AND
       (5 <= n_t1c AND n_t1c <= 15) AND
       n_nrsum2 >= 2)
     THEN
                     n_reh_l = 1;

   END;



*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++          ;
*Step V.  Test Extensive Services qualification.                             ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++          ;
                                                                             ;
*-------------------------------                                             ;
*Determine qualification for Extensive Services.                             ;
                                                                             ;
*Check for required Extensive Services indicators.                           ;
   *-------------------------------                                          ;
   *Resident qualifies for Extensive Services category on the basis of       ;
   *clinical indicators.                                                     ;
   *   Qualifications:                                                       ;
   *      Parenteral/IV feedings (k5a) OR IV medication (p1ac) OR            ;
   *      suctioning (p1ai) OR tracheostomy care (p1aj) OR                   ;
   *      ventilator or respirator (p1al).                                   ;

   *-------------------------------                                          ;

IF (  k5a  = '1'  OR
      p1ac = '1'  OR
      p1ai = '1'  OR
      p1aj = '1'  OR
      p1al = '1')
  THEN
   n_ext = 1;



*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++          ;
*Step VI.  Test Special Care qualification.                                  ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++          ;

*-------------------------------                                             ;
*Code count of all levels of ulcer (n_ulcer) for Special Care                ;
*   qualification                                                            ;
n_ulcer = 0;
IF ('1' <=   m1a AND   m1a <= '9')      THEN
   n_ulcer = n_ulcer + INPUT(  m1a,1.);

IF ('1' <=   m1b AND   m1b <= '9')      THEN
   n_ulcer = n_ulcer + INPUT(  m1b,1.);

IF ('1' <=   m1c AND   m1c <= '9')      THEN
   n_ulcer = n_ulcer + INPUT(  m1c,1.);

IF ('1' <=   m1d AND   m1d <= '9')      THEN
   n_ulcer = n_ulcer + INPUT(  m1d,1.);


*-------------------------------                                             ;
*Code count of selected skin care treatments for Special Care                ;
*   qualification                                                            ;
n_sk_tr = 0;
IF   m5a = '1'  OR    m5b = '1'  THEN
   n_sk_tr = n_sk_tr + 1;

IF   m5c = '1'                   THEN
   n_sk_tr = n_sk_tr + 1;

IF   m5d = '1'                   THEN
   n_sk_tr = n_sk_tr + 1;

IF   m5e = '1'                   THEN
   n_sk_tr = n_sk_tr + 1;

IF   m5g = '1'                   THEN
n_sk_tr = n_sk_tr + 1;

IF   m5h = '1'                   THEN
   n_sk_tr = n_sk_tr + 1;


*-------------------------------                                             ;
*Check for required Special Care clinical indicators                         ;
         *-------------------------------                                    ;
         *Resident qualifies for Special Care category on the basis of       ;
         *clinical indicators.                                               ;
         *   Qualifications (any one sufficient):                            ;
         *      1. Two or more ulcers of any type (n_ulcer) OR stage 3       ;
         *         or 4 pressure ulcer (m2a)                                 ;
         *            AND                                                    ;
         *         two or more selected skin care treatments (n_sk_tr).      ;
         *      2. Feeding tube (k5b) WITH parenteral/enteral intake         ;
         *         (n_intake) AND aphasia (i1r).                             ;
         *      3. Surgical wounds (m4g) OR open lesions other than          ;
         *         ulcers, rashes, cuts (m4c)                                ;
         *            AND                                                    ;
         *         surgical wound care (m5f) OR application of               ;
         *         dressings (m5g) OR application of ointments (m5h).        ;
         *      4. Respiratory therapy for 7 days (p1bda).                   ;
         *      5. Cerebral palsy (i1s) AND ADL score of 10 or more          ;
         *         (iAdlSum).                                                ;
         *      6. Fever (j1h)                                               ;
         *            AND                                                    ;
         *         vomiting (j1o) OR weight loss (k3a) OR tube feeding       ;
         *         (k5b) WITH high parenteral/enteral intake (n_intake)      ;
         *         OR pneumonia (i2e) OR dehydrated (j1c).                   ;
         *      7. Multiple sclerosis (i1w) AND ADL score of 10 or more      ;
         *         (iAdlSum).                                                ;
         *      8. Quadriplegia (i1z) AND ADL score of 10 or more            ;
         *         (iAdlSum).                                                ;
         *      9. Radiation therapy (p1ah).                                 ;

IF (      ((n_ulcer >= 2  OR    m2a = '3'  OR    m2a = '4')
              AND
           n_sk_tr >= 2)
      OR  ((  k5b = '1'  AND  n_intake = 1)  AND    i1r='1'  )
      OR  ((  m4g = '1'  OR    m4c = '1')
              AND
           (  m5f = '1'  OR    m5g = '1'  OR    m5h='1'))
      OR     p1bda = '7'
      OR  (  i1s = '1'  AND  iAdlSum >= 10)
      OR  (  j1h = '1'
              AND
           (  j1o = '1'
                  OR    k3a = '1'
                  OR  (  k5b= '1'  AND  n_intake = 1)
                  OR    i2e='1'
                  OR    j1c='1'))
      OR  (  i1w  = '1'  AND  iAdlSum >= 10)
      OR  (  i1z  = '1'  AND  iAdlSum >= 10)
      OR    p1ah = '1')
  THEN
         n_spec = 1;



*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++          ;
*Step VII. Test Clinically Complex qualification.                            ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++          ;

*-------------------------------                                             ;
*Calculate the number of periods the resident is not awake (n_n_awak).       ;
*   This variable is used in determining whether the resident is comatose    ;
*   or not.  This calculation influences qualification for both Clinically   ;
*   Complex and Cognitive Impairment.  This count (n_n_awak) is based on     ;
*   items n1a, n1b, and n1c.  For RUG-III classification, it is assumed      ;
*   that the resident is not awake, only if the response to an item is a     ;
*   0 (zero).  If the response to an item is '-' (unknown), then it is       ;
*   treated as if the resident were awake for that period.                   ;
n_n_awak = 0;
IF   n1a = '0'   THEN
   n_n_awak = n_n_awak + 1;

IF   n1b = '0'   THEN
   n_n_awak = n_n_awak + 1;

IF   n1c = '0'   THEN
   n_n_awak = n_n_awak + 1;


*-------------------------------                                             ;
*Calculate n_coma indicating whether the resident is comatose with qualifiers;
*      n_coma = 1 if resident is comatose (b1 = 1) and not awake all three   ;
*                 periods (n_n_awak = 3) and ADL dependent (g1aa, g1ba, g1ha,;
*                 and g1ia all have values of '4' or '8').                   ;
*             = 0 otherwise.                                                 ;

n_coma = 0;

IF (           b1 = '1'
        AND  n_n_awak  = 3
        AND  (  g1aa = '4'  OR    g1aa = '8')
        AND  (  g1ba = '4'  OR    g1ba = '8')
        AND  (  g1ha = '4'  OR    g1ha = '8')
        AND  (  g1ia = '4'  OR    g1ia = '8') )
  THEN
           n_coma = 1;



*-------------------------------                                             ;
*Make numeric versions of p7 and p8 for ease of coding, setting value to 0   ;
*   if item dash filled (value of '--').                                     ;
n_p7 = 0;
IF   p7 NE '--'             THEN
      n_p7 = INPUT(  p7,2.);

n_p8 = 0;
IF   p8 NE '--'             THEN
      n_p8 =INPUT(  p8,2.);


*-------------------------------                                             ;
*Check for Clinically Complex qualification.                                 ;
         *Resident qualifies for Clinically Complex category on the basis of ;
         *clinical indicators.                                               ;
         *-------------------------------                                    ;
         *   Qualifications (any one sufficient):                            ;
         *      1. Feeding tube (k5b) WITH high parenteral/enteral           ;
         *         intake (n_intake).                                        ;
         *      2. Comatose (b1) AND not awake (n_n_awak) AND                ;
         *         ADL dependent (g1aa, g1ba, g1ha, g1ia).                   ;
         *      3. Septicemia (i2g).                                         ;
         *      4. Burns--second or third degree (m4b).                      ;
         *      5. Dehydration (j1c).                                        ;
         *      6. Hemiplegia/hemiparesis (i1v) and ADL score of             ;
         *         10 or more (iAdlSum).                                     ;
         *      7. Internal bleeding (j1j).                                  ;
         *      8. Pneumonia (i2e).                                          ;
         *      9. End stage disease (j5c).-removed from 5.12                ;
         *     10. Chemotherapy (p1aa).                                      ;
         *     11. Dialysis (p1ab).                                          ;
         *     12. Physician order changes (p8) on 4 or more days            ;
         *         AND physician visits (p7) on 1 or more days.              ;
         *     13. Physician order changes (p8) on 2 or more days            ;
         *         AND physician visits (p7) on 2 or more days.              ;
         *     14. Diabetes (i1a) AND injections (o3) on 7 days              ;
         *         AND physician order changes (p8) on 2 or more             ;
         *         days.                                                     ;
         *     15. Transfusions (p1ak).                                      ;
         *     16. Oxygen therapy (p1ag).                                    ;
         *     17. Infection on foot (m6b) OR open lesion on foot (m6c)      ;
         *            AND                                                    ;
         *         application of dressings to foot (m6f).                   ;

IF (      (  k5b  = '1'  AND  n_intake = 1)
      OR  n_coma = 1
      OR    i2g = '1'
      OR    m4b = '1'
      OR    j1c = '1'
      OR  (  i1v = '1'  AND  iAdlSum >= 10)
      OR    j1j = '1'
      OR    i2e = '1'
 /*   OR    j5c = '1'  */
      OR    p1aa = '1'
      OR    p1ab = '1'
      OR  ((4 <= n_p8  AND  n_p8 <= 14)  AND
           (1 <= n_p7  AND  n_p7 <= 14))
      OR  ((2 <= n_p8  AND  n_p8 <= 14)  AND
           (2 <= n_p7  AND  n_p7 <= 14))
      OR  (  i1a= '1'  AND    o3 = '7'
              AND  (2 <= n_p8  AND  n_p8 <= 14))
      OR    p1ak = '1'
      OR    p1ag = '1'
      OR  ((  m6b = '1'  OR    m6c = '1')
              AND  (  m6f = '1' ))  )
  THEN
         n_clin = 1;



*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
*Step VIII.  Determine depression variable (n_depres) needed                 ;
*               for splitting the Clinically Complex Category.               ;
*            n_depres is a depression flag indicating presence of            ;
*               depression (value 1) or absence of depression (value 0).     ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

*-------------------------------                                             ;
*Determine count of depression indicators (n_mood)                           ;
n_mood = 0;
IF   e1a = '1'  OR    e1a = '2'  THEN
   n_mood = n_mood +1;

IF   e1b = '1'  OR    e1b = '2'  THEN
   n_mood = n_mood +1;

IF   e1c = '1'  OR    e1c = '2'  THEN
   n_mood = n_mood +1;

IF   e1d = '1'  OR    e1d = '2'  THEN
   n_mood = n_mood +1;

IF   e1e = '1'  OR    e1e = '2'  THEN
   n_mood = n_mood +1;

IF   e1f = '1'  OR    e1f = '2'  THEN
   n_mood = n_mood +1;

IF   e1g = '1'  OR    e1g = '2'  THEN
   n_mood = n_mood +1;

IF   e1h = '1'  OR    e1h = '2'  THEN
   n_mood = n_mood +1;

IF   e1i = '1'  OR    e1i = '2'  THEN
   n_mood = n_mood +1;

IF   e1j = '1'  OR    e1j = '2'  THEN
   n_mood = n_mood +1;

IF   e1k = '1'  OR    e1k = '2'  THEN
   n_mood = n_mood +1;

IF   e1l = '1'  OR    e1l = '2'  THEN
   n_mood = n_mood +1;

IF   e1m = '1'  OR    e1m = '2'  THEN
   n_mood = n_mood +1;

IF   e1n = '1'  OR    e1n = '2'  THEN
   n_mood = n_mood +1;

IF   e1o = '1'  OR    e1o = '2'  THEN
   n_mood = n_mood +1;

IF   e1p = '1'  OR    e1p = '2'  THEN
   n_mood = n_mood +1;


*-------------------------------                                             ;
*Set depression flag (n_depres).                                             ;
IF n_mood >= 3   THEN
   n_depres = 1;
ELSE
   n_depres = 0;


*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++                  ;
*Step IX. Test Cognitive Impairment qualification.                           ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++                  ;
*                                                                            ;
*Note:  RUG-III Cognitive Impairment qualification is based on               ;
*       the Cognitive Performance Scale.                                     ;
*                                                                            ;
*   Details concerning this scale are available in:                          ;
*                                                                            ;
*       Morris JN, Fries BE, Morris JN, Fries BE, Mehr DR, Hawes C,          ;
*       Phillips C, Mor V, and Lipsitz LA.  "MDS Cognitive Performance       ;
*       Scale" J. Gerontology: Medical Sciences 49(4):M174-M182 (July)       ;
*       1994.                                                                ;
*                                                                            ;
*   For use in RUG-III classification, the Cognitive Performance             ;
*   Scale logic has been modified to use the same qualifiers for             ;
*   a comatose condition as used for Clinically Complex qualification.       ;
*                                                                            ;
*   Note that a previously calculated variable, n_coma, is used in the       ;
*   Cognitive Performance Scale.                                             ;
*      n_coma = 1 if resident is comatose (b1 = 1) and not awake             ;
*                 (n_n_awak = 3) and ADL dependent (g1aa, g1ba, g1ha, and    ;
*                 g1ia all have values of '4' or '8').                       ;
*             = 0 otherwise.                                                 ;
                                                                             ;
*-------------------------------                                             ;
*Calculate n_cog1 and n_cog2 variables used in Cognitive Performance Scale.  ;
*   n_cog1 is a count of non-independence on three items (b2a, b4, and       ;
*          c4).                                                              ;
*   n_cog2 is a count of moderate to severe impairment on two items          ;
*          (b4 and c4).                                                      ;
*                                                                            ;
*   Both n_cog1 and n_cog2 have default values of -1 (missing) and are       ;
*   only calculated if item b2a is in the range 0 to 1, item b4 is in        ;
*   the range 0 to 3, and item c4 is in the range 0 to 3.                    ;

n_cog1 = -1;
n_cog2 = -1;

IF ((  b2a >= '0'  AND    b2a <= '1')  AND
    (  b4  >= '0'  AND    b4  <= '3')  AND
    (  c4  >= '0'  AND    c4  <= '3') )
  THEN DO;
       n_cog1 = 0;
       IF (  b2a = '1')                                 THEN
          n_cog1 = n_cog1 + 1;

       IF (  b4 = '1'  OR    b4 = '2')                  THEN
          n_cog1 = n_cog1 + 1;

       IF (  c4 = '1'  OR    c4 = '2'  OR    c4 = '3')  THEN
          n_cog1 = n_cog1 + 1;


       n_cog2 = 0;
       IF (  b4 = '2')                                  THEN
          n_cog2 = n_cog2 + 1;

       IF (  c4 = '2'  OR    c4 = '3')                  THEN
          n_cog2 = n_cog2 + 1;

       END;


*-------------------------------                                             ;
*Calculate iCpsCode--Cognitive Performance Scale .                           ;
*                                                                            ;
*   Cognitive Performance Scale Codes:                                       ;
*          0 = intact                                                        ;
*          1 = borderline intact                                             ;
*          2 = mild impairment                                               ;
*          3 = moderate impairment                                           ;
*          4 = moderately severe impairment                                  ;
*          5 = severe impairment                                             ;
*          6 = very severe impairment                                        ;

*Set iCpsCode to a default of 0 and calculate                                   
;
iCpsCode = 0;

IF     (n_coma = 1  AND
         NOT  (  b4 = '0'  OR    b4 = '1'  OR    b4 = '2'))      THEN
                 iCpsCode = 6;
ELSE IF   b4= '3'                                                THEN DO;
       IF     (  g1ha = '4'  OR    g1ha = '8')                   THEN
                 iCpsCode = 6;
       ELSE IF (  g1ha = '-'  OR    g1ha = '0'  OR    g1ha = '1'
                OR    g1ha ='2'  OR    g1ha ='3')                THEN
                 iCpsCode = 5;
       END;
ELSE IF (n_cog1 = 2  OR  n_cog1 = 3)                             THEN DO;
       IF     n_cog2 = 2                                         THEN
                 iCpsCode = 4;
       ELSE IF n_cog2 = 1                                        THEN
                 iCpsCode = 3;
       ELSE IF n_cog2 = 0                                        THEN
                 iCpsCode = 2;
       END;
ELSE IF n_cog1 = 1                                               THEN
                 iCpsCode = 1;


*-------------------------------                                             ;
*Determine Cognitive Impairment qualification.                               ;
*   Qualification if Cognitive Performance Scale is 3 or more.               ;

IF iCpsCode >= 3
  THEN
   n_impair = 1;



*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++                  ;
*Step X. Test Behavior Problems qualification.                               ;
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++                  ;

*-------------------------------                                             ;
*Check for Behavior Problems qualification.                                  ;
         *-------------------------------                                    ;
         *Behavior Problems Qualifications (any one sufficient):             ;
         *      1. Wandering occurred on 4 or more days (e4aa).              ;
         *      2. Verbally abusive behavior occurred on 4 or more           ;
         *         days (e4ba).                                              ;
         *      3. Physically abusive behavior occurred on 4 or              ;
         *         more days (e4ca).                                         ;
         *      4. Socially inappropriate/disruptive behavior                ;
         *         occurred on 4 or more days (e4da).                        ;
         *      5. Resident resisted care on 4 or more days (e4ea).          ;
         *      6. Hallucinations (j1i).                                     ;
         *      7. Delusions (j1e).                                          ;

IF (     (  e4aa = '2'  OR    e4aa =  '3')
     OR  (  e4ba = '2'  OR    e4ba =  '3')
     OR  (  e4ca = '2'  OR    e4ca =  '3')
     OR  (  e4da = '2'  OR    e4da =  '3')
     OR  (  e4ea = '2'  OR    e4ea =  '3')
     OR  (  j1i = '1')
     OR  (  j1e = '1'))
   THEN
         n_behav = 1;

*++++++++++++++++++++++++++++++++++++++++                                    ;
*Step XI. Classify into RUG-III Groups                                       ;
*++++++++++++++++++++++++++++++++++++++++                                    ;

*NOTE:  nCmiValueMax is used to control both index maximizing and            ;
*   hierarchical classification.  At this point nCmiValueMax is the initial  ;
*   value of 9999, and this initial value indicates that neither index      ;
*   maximizing nor hierarchical classification has been made yet.            ;

*===============================                                             ;
*Begin Classification into 53-group Rehab/Extensive Groups*****              ;
IF sModel = '53' 
THEN DO;

* All final splits based on ADL sum (iAdlSum).                               ;

*-------------------------------                                             ;
*Classify into Ultra High Intensity Rehab Plus Extensive groups*****         ;
*                                                                            ;
*   Classify if Ultra High Rehab and Extensive indicators present.           ;
*                                                                            ;
*   Determine final splits for Ultra High Rehab Plus Extensive residents     ;
*   on the basis of ADL sum.                                                 ;

IF n_reh_u = 1 AND (n_ext = 1  AND  iAdlSum >=7) 
THEN DO;

   IF     (16 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(1) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO; 
                   nCmiValueHier = nCmiArray(1);
                   sRugHier = 'RUX'; 
                   nRugHier = 1;
                END;
                nCmiValueMax = nCmiArray(1);
                sRugMax = 'RUX';
                nRugMax = 1;
             END;
   END;

   ELSE IF     (7 <= iAdlSum  AND  iAdlSum <= 15)
   THEN DO;
             IF nCmiArray(2) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(2);
                   sRugHier = 'RUL'; 
                   nRugHier = 2;
                END;
                nCmiValueMax = nCmiArray(2);
                sRugMax = 'RUL';
                nRugMax = 2;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Very High Intensity Rehab Plus Extensive groups*****          ;
*                                                                            ;
*   Classify if Very High Rehab and Extensive indicators present and         ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for Very High Rehab Plus Extensive residents      ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF n_reh_v = 1 AND (n_ext = 1  AND  iAdlSum >=7) 
THEN DO;

   IF     (16 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(3) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(3);
                   sRugHier = 'RVX'; 
                   nRugHier = 3;
                END;
                nCmiValueMax = nCmiArray(3);
                sRugMax = 'RVX';
                nRugMax = 3;
             END;
   END;

   ELSE IF     (7 <= iAdlSum  AND  iAdlSum <= 15)
   THEN DO;
             IF nCmiArray(4) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(4);
                   sRugHier = 'RVL'; 
                   nRugHier = 4;
                END;
                nCmiValueMax = nCmiArray(4);
                sRugMax = 'RVL';
                nRugMax = 4;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into High Intensity Rehab Plus Extensive groups*****               ;
*                                                                            ;
*   Classify if High Rehab and Extensive indicators present and              ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for High Rehab Plus Extensive residents           ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF n_reh_h = 1 AND (n_ext = 1  AND  iAdlSum >=7) 
THEN DO;

   IF     (13 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(5) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(5);
                   sRugHier = 'RHX'; 
                   nRugHier = 5;
                END;
                nCmiValueMax = nCmiArray(5);
                sRugMax = 'RHX';
                nRugMax = 5;
             END;
   END;

   ELSE IF     (7 <= iAdlSum  AND  iAdlSum <= 12)
   THEN DO;
             IF nCmiArray(6) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(6);
                   sRugHier = 'RHL'; 
                   nRugHier = 6;
                END;
                nCmiValueMax = nCmiArray(6);
                sRugMax = 'RHL';
                nRugMax = 6;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Medium Intensity Rehab Plus Extensive groups*****             ;
*                                                                            ;
*   Classify if Medium Rehab and Extensive indicators present and            ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for Medium Rehab Plus Extensive residents         ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF n_reh_m = 1 AND (n_ext = 1  AND  iAdlSum >=7) 
THEN DO;

   IF     (15 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(7) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(7);
                   sRugHier = 'RMX'; 
                   nRugHier = 7;
                END;
                nCmiValueMax = nCmiArray(7);
                sRugMax = 'RMX';
                nRugMax = 7;
             END;
   END;

   ELSE IF     (7 <= iAdlSum  AND  iAdlSum <= 14)
   THEN DO;
             IF nCmiArray(8) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(8);
                   sRugHier = 'RML'; 
                   nRugHier = 8;
                END;
                nCmiValueMax = nCmiArray(8);
                sRugMax = 'RML';
                nRugMax = 8;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Low Intensity Rehab Plus Extensive group*****                 ;
*                                                                            ;
*   Classify if Low Rehab and Extensive indicators present and               ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Accept classification into the Low Rehab Plus Extensive group if CMI     ;
*   for that group is higher than previous high CMI.                         ;

IF n_reh_l = 1 AND (n_ext = 1  AND  iAdlSum >=7) 
THEN DO;

   IF     (7 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(9) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999 
                THEN DO; 
                   nCmiValueHier = nCmiArray(9);
                   sRugHier = 'RLX'; 
                   nRugHier = 9;
                END;
                nCmiValueMax = nCmiArray(9);
                sRugMax = 'RLX';
                nRugMax = 9;
             END;
   END;
END;


*End Classification into 53-group Rehab/ Extensive Groups*****               ;
END;
*===============================                                             ;

*===============================                                             ;
*Begin Classification into 44- and 53-group Rehab Groups*****                ;
IF sModel = '44' OR sModel = '53' 
THEN DO;

* All final splits based on ADL sum (iAdlSum).                               ;

*-------------------------------                                             ;
*Classify into Ultra High Intensity Rehab groups*****                        ;
*                                                                            ;
*   Classify if Ultra High Rehab indicators present and                      ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for Ultra High Intensity Rehab residents          ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF n_reh_u = 1
THEN DO;

   IF     (16 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(10) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO; 
                   nCmiValueHier = nCmiArray(10);
                   sRugHier= 'RUC'; 
                   nRugHier=10; 
                END;
                nCmiValueMax = nCmiArray(10);
                sRugMax= 'RUC';
                nRugMax=10;
             END;
   END;

   ELSE IF ( 9 <= iAdlSum  AND  iAdlSum <= 15)
   THEN DO;
             IF nCmiArray(11) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO; 
                   nCmiValueHier = nCmiArray(11);
                   sRugHier= 'RUB';
                   nRugHier=11;
                END;
                nCmiValueMax = nCmiArray(11);
                sRugMax= 'RUB';
                nRugMax=11;
              END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <=  8)  
   THEN DO;
             IF nCmiArray(12) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(12);
                   sRugHier= 'RUA';
                   nRugHier=12;
                END;
                nCmiValueMax = nCmiArray(12);
                sRugMax= 'RUA';
                nRugMax=12;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Very High Intensity Rehab groups*****                         ;
*                                                                            ;
*   Classify if Very High rehab indicators present and                       ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for Very High Intensity Rehab residents           ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;
                                                                             ;
IF (n_reh_v = 1)  
THEN DO;

   IF     (16 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(13) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(13);
                   sRugHier= 'RVC';
                   nRugHier=13;
                END;
                nCmiValueMax = nCmiArray(13);
                sRugMax= 'RVC';
                nRugMax=13;
             END;
   END;

   ELSE IF ( 9 <= iAdlSum  AND  iAdlSum <= 15)
   THEN DO;
             IF nCmiArray(14) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(14);
                   sRugHier= 'RVB';
                   nRugHier=14;
                END;
                nCmiValueMax = nCmiArray(14);
                sRugMax= 'RVB';
                nRugMax=14;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <=  8)
   THEN DO;
             IF nCmiArray(15) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(15);
                   sRugHier= 'RVA';
                   nRugHier=15;
                END;
                nCmiValueMax = nCmiArray(15);
                sRugMax= 'RVA';
                nRugMax=15;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into High Intensity Rehab groups*****                              ;
*                                                                            ;
*   Classify if High Rehab indicators present and                            ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for High Intensity Rehab residents                ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF (n_reh_h = 1)
THEN DO;

   IF     (13 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(16) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(16);
                   sRugHier= 'RHC';
                   nRugHier=16;
                END;
                nCmiValueMax = nCmiArray(16);
                sRugMax= 'RHC';
                nRugMax=16;
             END;
   END;

   ELSE IF ( 8 <= iAdlSum  AND  iAdlSum <= 12)
   THEN DO;
             IF nCmiArray(17) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(17);
                   sRugHier= 'RHB';
                   nRugHier=17;
                END;
                nCmiValueMax = nCmiArray(17);
                sRugMax= 'RHB';
                nRugMax=17;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <=  7)
   THEN DO;
             IF nCmiArray(18) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(18);
                   sRugHier= 'RHA';
                   nRugHier=18;
                END;
                nCmiValueMax = nCmiArray(18);
                sRugMax= 'RHA';
                nRugMax=18;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Medium Intensity Rehab groups*****                            ;
*                                                                            ;
*   Classify if Medium Rehab indicators present and                          ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for Medium Intensity Rehab residents              ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF (n_reh_m = 1)
THEN DO;

   IF     (15 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(19) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(19);
                   sRugHier= 'RMC';
                   nRugHier=19;
                END;
                nCmiValueMax = nCmiArray(19);
                sRugMax= 'RMC';
                nRugMax=19;
             END;
   END;

   ELSE IF ( 8 <= iAdlSum  AND  iAdlSum <= 14)
   THEN DO;
             IF nCmiArray(20) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(20);
                   sRugHier= 'RMB';
                   nRugHier=20;
                END;
                nCmiValueMax = nCmiArray(20);
                sRugMax= 'RMB';
                nRugMax=20;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <=  7)
   THEN DO;
             IF nCmiArray(21) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(21);
                   sRugHier= 'RMA';
                   nRugHier=21;
                END;
                nCmiValueMax = nCmiArray(21);
                sRugMax= 'RMA';
                nRugMax=21;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Low Intensity Rehab groups*****                               ;
*                                                                            ;
*   Classify if Low Rehab indicators present and                             ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for Low Intensity Rehab residents                 ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF (n_reh_l = 1)
THEN DO;

   IF     (14 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(22) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(22);
                   sRugHier= 'RLB';
                   nRugHier=22;
                END;
                nCmiValueMax = nCmiArray(22) ;
                sRugMax= 'RLB';
                nRugMax=22;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <= 13)
   THEN DO;
             IF nCmiArray(23) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(23);
                   sRugHier= 'RLA';
                   nRugHier=23;
                END;
                nCmiValueMax = nCmiArray(23);
                sRugMax= 'RLA';
                nRugMax=23;
             END;
   END;

END;

*End Classification into 44- and 53-group Rehab Groups*****                  ;
END;
*===============================                                             ;

*-------------------------------                                             ;
*Classify into Extensive Services Groups (34-, 44-, and 53-group models)*****;
*                                                                            ;
*To be classified as Extensive Services a resident must qualify on the       ;
*    basis of having Extensive Services clinical indicators (n_ext = 1)  AND ;
*    an ADL sum of 7 or more  AND                                            ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*    Note that residents who have Extensive Services clinical indicators but ;
*    have too low an ADL score (6 or less) are classified as Special Care    ;
*    rather than Extensive Services.                                         ;
*                                                                            ;
*Split into Extensive Services groups is based on a count (n_ext_ct) of other;
*   hierarchy category qualifications plus existence of                      ;
*   parenteral/IV feeding (k5a) and IV medications (p1ac).  Accept           ;
*   classification into a group if CMI for that group is higher than         ;
*   previous high CMI.                                                       ;

IF  (n_ext = 1  AND  iAdlSum >=7)
THEN DO;

   n_ext_ct = n_spec + n_clin + n_impair;
   IF   k5a = '1'  THEN
      n_ext_ct = n_ext_ct + 1;

   IF   p1ac= '1'  THEN
      n_ext_ct = n_ext_ct + 1;


   IF     (4 <= n_ext_ct  AND  n_ext_ct <= 5)
   THEN DO;
             IF nCmiArray(24) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(24);
                   sRugHier= 'SE3';
                   nRugHier=24;
                END;
                nCmiValueMax = nCmiArray(24);
                sRugMax= 'SE3';
                nRugMax=24;
             END;
   END;

   ELSE IF (2 <= n_ext_ct  AND  n_ext_ct <= 3)
   THEN DO;
             IF nCmiArray(25) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(25);
                   sRugHier= 'SE2';
                   nRugHier=25;
                END;
                nCmiValueMax = nCmiArray(25);
                sRugMax= 'SE2';
                nRugMax=25;
             END;
   END;

   ELSE IF (0 <= n_ext_ct  AND  n_ext_ct <= 1)
   THEN DO;
             IF nCmiArray(26) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(26);
                   sRugHier= 'SE1';
                   nRugHier=26;
                END;
                nCmiValueMax = nCmiArray(26);
                sRugMax= 'SE1';
                nRugMax=26;
             END;
   END;
END;

*===============================                                             ;
*Begin Classification into 34-group Rehab Groups*****                        ;
IF sModel = '34' 
THEN DO;

*-------------------------------                                             ;
*Classify into 34-group model Rehab groups*****                              ;
*                                                                            ;
*   Classify if any rehab indicator (ultra high, very high, high, medium or  ;
*   low) present and                                                         ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Determine final splits for Low Intensity Rehab residents                 ;
*   on the basis of ADL sum.  Accept classification into a group if CMI      ;
*   for that group is higher than previous high CMI.                         ;

IF (n_reh_u = 1 OR n_reh_v = 1 OR n_reh_h = 1 OR n_reh_m = 1 OR n_reh_l = 1)
THEN DO;

   IF     (17 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(27) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(27);
                   sRugHier= 'RAD';
                   nRugHier=27;
                END;
                nCmiValueMax = nCmiArray(27) ;
                sRugMax= 'RAD';
                nRugMax=27;
             END;
   END;

   ELSE IF ( 14 <= iAdlSum  AND  iAdlSum <= 16)
   THEN DO;
             IF nCmiArray(28) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(28);
                   sRugHier= 'RAC';
                   nRugHier=28;
                END;
                nCmiValueMax = nCmiArray(28);
                sRugMax= 'RAC';
                nRugMax=28;
             END;
   END;

   ELSE IF (10 <= iAdlSum  AND  iAdlSum <= 13)
   THEN DO;
             IF nCmiArray(29) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(29);
                   sRugHier= 'RAB';
                   nRugHier=29;
                END;
                nCmiValueMax = nCmiArray(29);
                sRugMax= 'RAB';
                nRugMax=29;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <= 9)
   THEN DO;
             IF nCmiArray(30) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(30);
                   sRugHier= 'RAA';
                   nRugHier=30;
                END;
                nCmiValueMax = nCmiArray(30);
                sRugMax= 'RAA';
                nRugMax=30;
             END;
   END;
END;

*End Classification into 34-group Rehab Groups*****                          ;
END;
*===============================                                             ;

*-------------------------------                                             ;
*Classify into Special Care Groups (34-, 44-, and 53-group models)*****      ;
*                                                                            ;
*To be classified as Special Care a resident must satisfy one of the         ;
*   three following conditions:                                              ;
*   1. The resident has both Special Care clinical indicators (n_spec = 1)   ;
*      and an ADL sum of 7 or more, regardless of calculation method.        ;
*   2. The calculation method is Hierarchical and the resident has both      ;
*      Extensive Services indicators (n_ext = 1) and an ADL sum of 6 or less.;
*   3. The calculation method is Index Maximizing and the resident           ;
*      has Extensive Services clinical indicators (n_ext = 1) with           ;
*      any ADL sum.                                                          ;
*                                                                            ;
*   Classify if one of these 3 conditions present and                        ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*   Note that residents who have Special Care clinical indicators but        ;
*   have too low an ADL score (6 or less) are classified as Clinically       ;
*   Complex rather than Special Care.                                        ;
*                                                                            ;
*Split into Special Care groups is based on ADL sum.  Accept classification  ;
*   into a group if CMI for that group is higher than previous high CMI.     ;

IF  ((n_spec = 1  AND  iAdlSum >= 7)  OR  n_ext = 1)
THEN DO;

   IF     (17 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF nCmiArray(31) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(31);
                   sRugHier= 'SSC';
                   nRugHier=31;
                END;
                nCmiValueMax = nCmiArray(31);
                sRugMax= 'SSC';
                nRugMax=31;
             END;
   END;

   ELSE IF (15 <= iAdlSum  AND  iAdlSum <= 16)
   THEN DO;
             IF nCmiArray(32) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(32);
                   sRugHier= 'SSB';
                   nRugHier=32;
                END;
                nCmiValueMax = nCmiArray(32);
                sRugMax= 'SSB';
                nRugMax=32;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <= 14)
   THEN DO;
             IF nCmiArray(33) > nCmiValueMax
             THEN DO;
                IF nCmiValueMax = -9999
                THEN DO;
                   nCmiValueHier = nCmiArray(33);
                   sRugHier= 'SSA';
                   nRugHier=33;
                END;
                nCmiValueMax = nCmiArray(33);
                sRugMax= 'SSA';
                nRugMax=33;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Clinically Complex Groups (34-, 44-, and 53-group models)*****;
*To be classified as Clinically Complex a resident must satisfy one of the   ;
*   four following conditions:                                               ;
*   1. The resident has Clinically Complex clinical indicators (n_clin = 1), ;
*      regardless of calculation method.                                     ;
*   2. The calculation method is Hierarchical and the resident has both      ;
*      Special Care indicators (n_spec = 1) and an ADL sum of 6 or less.     ;
*   3. The calculation method is Index Maximizing and the resident           ;
*      has Special Care clinical indicators (n_spec = 1) with                ;
*      any ADL sum.                                                          ;
*   4. The calculation method is Index Maximizing and the resident           ;
*      has Extensive Services clinical indicators (n_ext = 1) with           ;
*      any ADL sum.                                                          ;
*                                                                            ;
*   Classify if one of these 4 conditions present and                        ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*                                                                            ;
*Split into Clinically Complex groups is based on ADL sum and depression.    ;
*   Accept classification into a group if CMI for that group is higher       ;
*   than previous high CMI.                                                  ;

IF  (n_clin = 1  OR  n_spec = 1  OR  n_ext = 1)
THEN DO;

   IF     (17 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF n_depres = 1
             THEN DO;
                IF nCmiArray(34) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(34);
                      sRugHier= 'CC2';
                      nRugHier=34;
                   END;
                   nCmiValueMax = nCmiArray(34);
                   sRugMax= 'CC2';
                   nRugMax=34;
                END;
             END;
             ELSE
             DO; 
                IF nCmiArray(35) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(35);
                      sRugHier= 'CC1';
                      nRugHier=35;
                   END;
                   nCmiValueMax = nCmiArray(35);
                   sRugMax= 'CC1';
                   nRugMax=35;
                END;
             END;
   END;

   ELSE IF (12 <= iAdlSum  AND  iAdlSum <= 16)
   THEN DO;
             IF n_depres = 1
             THEN DO;
                IF nCmiArray(36) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(36);
                      sRugHier= 'CB2';
                      nRugHier=36;
                   END;
                   nCmiValueMax = nCmiArray(36);
                   sRugMax= 'CB2';
                   nRugMax=36;
                END;
             END;
             ELSE 
             DO;
                IF nCmiArray(37) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(37);
                      sRugHier= 'CB1';
                      nRugHier=37;
                   END;
                   nCmiValueMax = nCmiArray(37);
                   sRugMax= 'CB1';
                   nRugMax=37;
                END;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <= 11)
   THEN DO;
             IF n_depres = 1                
             THEN DO;
                IF nCmiArray(38) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(38);
                      sRugHier= 'CA2';
                      nRugHier=38;
                   END;
                   nCmiValueMax = nCmiArray(38);
                   sRugMax= 'CA2';
                   nRugMax=38;
                END;
             END;
             ELSE 
             DO;
                IF nCmiArray(39) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(39);
                      sRugHier= 'CA1';
                      nRugHier=39;
                   END;
                   nCmiValueMax = nCmiArray(39);
                   sRugMax= 'CA1';
                   nRugMax=39;
                END;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Cognitive Groups (34-, 44-, and 53-group models)*****         ;
*                                                                            ;
*To be classified as Cognitive Impairment the resident has Cognitive         ;
*   Impairment indicators (n_impair = 1)  and an ADL sum of 10 or less  and  ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*Split into Impaired Cognitive groups is based on ADL sum and nursing        ;
*   rehab count (n_nrsum6).  Accept classification into a group if CMI       ;
*   for that group is higher than previous high CMI.                         ;

IF  (n_impair = 1  AND  4 <= iAdlSum  AND  iAdlSum <= 10)
THEN DO;

   IF      ( 6 <= iAdlSum  AND  iAdlSum <= 10)
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(40) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(40);
                      sRugHier= 'IB2';
                      nRugHier=40;
                   END;
                   nCmiValueMax = nCmiArray(40);
                   sRugMax= 'IB2';
                   nRugMax=40;
                END;
             END;
             ELSE 
             DO;
                IF nCmiArray(41) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(41);
                      sRugHier= 'IB1';
                      nRugHier=41;
                   END;
                   nCmiValueMax = nCmiArray(41);
                   sRugMax= 'IB1';
                   nRugMax=41;
                END;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <=  5)
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(42) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(42);
                      sRugHier= 'IA2';
                      nRugHier=42;
                   END;
                   nCmiValueMax = nCmiArray(42);
                   sRugMax= 'IA2';
                   nRugMax=42;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(43) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(43);
                      sRugHier= 'IA1';
                      nRugHier=43;
                   END;
                   nCmiValueMax = nCmiArray(43);
                   sRugMax= 'IA1';
                   nRugMax=43;
                END;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Behavioral Problems Groups (34-, 44-, and 53-group models)****;
*                                                                            ;
*To be classified as Behavior Problems the resident has Behavior             ;
*   Problems indicators (n_behav = 1)  and an ADL sum of 10 or less          ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*                                                                            ;
*Split into Behavior Problems groups is based on ADL sum and nursing         ;
*   rehab count (n_nrsum6).  Accept classification into a group if CMI       ;
*   for that group is higher than previous high CMI.                         ;

IF  (n_behav = 1  AND  4 <= iAdlSum  AND  iAdlSum <= 10)
THEN DO;

   IF     ( 6 <= iAdlSum  AND  iAdlSum <= 10)
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(44) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(44);
                      sRugHier= 'BB2';
                      nRugHier=44;
                   END;
                   nCmiValueMax = nCmiArray(44);
                   sRugMax= 'BB2';
                   nRugMax=44;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(45) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(45);
                      sRugHier= 'BB1';
                      nRugHier=45;
                   END;
                   nCmiValueMax = nCmiArray(45);
                   sRugMax= 'BB1';
                   nRugMax=45;
                END;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <=  5)
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(46) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(46);
                      sRugHier= 'BA2';
                      nRugHier=46;
                   END;
                   nCmiValueMax = nCmiArray(46);
                   sRugMax= 'BA2';
                   nRugMax=46;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(47) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(47);
                      sRugHier= 'BA1';
                      nRugHier=47;
                   END;
                   nCmiValueMax = nCmiArray(47);
                   sRugMax= 'BA1';
                   nRugMax=47;
                END;
             END;
   END;
END;

*-------------------------------                                             ;
*Classify into Physical Groups (34-, 44-, and 53-group models)********       ;
*   A resident is classified as reduced Physical Function if                 ;
*      (1) a previous hierarchical classification has not been made          ;
*          (indicated by nCmiValueMax being at a default negative value)     ;
*   or (2) yields a higher rate for index maximization.                      ;
*                                                                            ;
*                                                                            ;
*Split into Physical Function groups is based on ADL sum and nursing         ;
*   rehab count (n_nrsum6).  Accept classification into a group if CMI       ;
*   for that group is higher than previous high CMI.                         ;

   IF     (16 <= iAdlSum  AND  iAdlSum <= 18)
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(48) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(48);
                      sRugHier= 'PE2';
                      nRugHier=48;
                   END;
                   nCmiValueMax = nCmiArray(48);
                   sRugMax= 'PE2';
                   nRugMax=48;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(49) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(49);
                      sRugHier= 'PE1';
                      nRugHier=49;
                   END;
                   nCmiValueMax = nCmiArray(49);
                   sRugMax= 'PE1';
                   nRugMax=49;
                END;
             END;
   END;

   ELSE IF (11 <= iAdlSum  AND  iAdlSum <= 15)
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(50) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(50);
                      sRugHier= 'PD2';
                      nRugHier=50;
                   END;
                   nCmiValueMax = nCmiArray(50);
                   sRugMax= 'PD2';
                   nRugMax=50;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(51) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(51);
                      sRugHier= 'PD1';
                      nRugHier=51;
                   END;
                   nCmiValueMax = nCmiArray(51);
                   sRugMax= 'PD1';
                   nRugMax=51;
                END;
             END;
   END;

   ELSE IF ( 9 <= iAdlSum  AND  iAdlSum <= 10)
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(52) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(52);
                      sRugHier= 'PC2';
                      nRugHier=52;
                   END;
                   nCmiValueMax = nCmiArray(52);
                   sRugMax= 'PC2';
                   nRugMax=52;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(53) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(53);
                      sRugHier= 'PC1';
                      nRugHier=53;
                   END;
                   nCmiValueMax = nCmiArray(53);
                   sRugMax= 'PC1';
                   nRugMax=53;
                END;
             END;
   END;

   ELSE IF ( 6 <= iAdlSum  AND  iAdlSum <=  8 )
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(54) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(54);
                      sRugHier= 'PB2';
                      nRugHier=54;
                   END;
                   nCmiValueMax = nCmiArray(54);
                   sRugMax= 'PB2';
                   nRugMax=54;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(55) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(55);
                      sRugHier= 'PB1';
                      nRugHier=55;
                   END;
                   nCmiValueMax = nCmiArray(55);
                   sRugMax= 'PB1';
                   nRugMax=55;
                END;
             END;
   END;

   ELSE IF ( 4 <= iAdlSum  AND  iAdlSum <=  5 )
   THEN DO;
             IF n_nrsum6 >= 2
             THEN DO;
                IF nCmiArray(56) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(56);
                      sRugHier= 'PA2';
                      nRugHier=56;
                   END;
                   nCmiValueMax = nCmiArray(56);
                   sRugMax= 'PA2';
                   nRugMax=56;
                END;
             END;
             ELSE
             DO;
                IF nCmiArray(57) > nCmiValueMax
                THEN DO;
                   IF nCmiValueMax = -9999
                   THEN DO;
                      nCmiValueHier = nCmiArray(57);
                      sRugHier= 'PA1';
                      nRugHier=57;
                   END;
                   nCmiValueMax = nCmiArray(57);
                   sRugMax= 'PA1';
                   nRugMax=57;
                END;
             END;
   END;

SKIPEND:

