/************************************************************************
*  Program to read MDS 2.0 submission file 'test5_20a.txt' and save a SAS 
*  data set 'test5_20.sas7bdat' containing the items needed to test 
*  RUG-III version 5.20 classification.
*
*     Adapted from the MDS 2.0 SAS input statement for extract files from
*     the national MDS 2.0 repository.
*************************************************************************/
 
*************************************************************************;
***                                                                     *;
***  SAS INPUT and LABEL Statements for Standard MDS Extract Files      *;
***             from the CMS's National MDS Repository                  *;
***                                                                     *;
***      Version 1.02   02/01/02                                        *;
***                                                                     *;
*************************************************************************;
  
/*** 
   The following SAS INPUT statement is designed to read a flat file
   containing Minimum Data Set, Version 2.0 (MDS 2.0) data.  This INPUT 
   statement is appropriate for use with Standard National MDS Repository 
   Extract Files.
 
   The INPUT statement defines all variables as character data.  The coding
   for most variables includes non-numeric values to indicate missing
   values.  Most variables in the extract file have 4 different missing
   value codes.  These missing value codes are dash ('-'), space (' '),
   asterisk ('*'), and ampersand ('&'). When a field is 2 or more characters
   long, then the field is filled to its length with the missing value code.
   For example, a 2-character field would contain '**', a 3-character field 
   would contain '***', etc. 
 
   The meaning of each of the 4 missing value codes is as follows:
 
      '-' indicates that the assessor addressed the item but was unable to 
          determine a response.
 
      ' ' indicates that the item was skipped and is not relevant on this MDS 
          assessment or tracking form.  For example, if b1 = 1 (resident 
          comatose), then B2a and B2b (memory items) are irrelevant, cannot be 
          assessed, and will be space filled.  See the MDS data specifications 
          to determine the skip patterns for MDS records.
 
      '*' indicates that the item was not active on this assessment or tracking 
          form (e.g., item not present on this quarterly assessment) or was out-
          of-range on submission.  For assessments submitted after 4/28/2000, 
          records will be rejected if there is an out-of-range value on most 
          fields (only exceptions are a few computed fields--Rec_type and the 
          RUGs fields T3mdrc and T3state).  For records submitted after 
          4/28/2000, an '*' will always indicate an inactive item.  For records 
          submitted before 4/28/2000, an '*' indicates the item was inactive or 
          out-of range.
 
      '&' indicates that the item was inactive.  This is an old coding 
          convention that should not occur in records submitted from the end of 
          April 1999 forward. 
 
   The non-missing values for most MDS items are limited to numeric codes.  If a 
   user does not need to distinguish between the 4 types of missing values, then 
   most items can be read as numeric or date fields. 
 
      For example, the line (numeric value):
             @1204    N_T1aB    4.     
      can be substituted for the line (character value): 
             @1204    n_T1aB    $CHAR4.
 
      Also the line (date value):
             @133  D_AT6  MMDDYY8.
      can be substituted for the line (character value):
             @133  D_AT6  $CHAR8.
 
   When read as numeric or date fields, all of the 4 missing value codes will be 
   set to the standard SAS missing value (.) on input.
 
   CAUTION:  Please note that a particular item may only be active on certain MDS 
   record types.  For example, the memory/recall items will usually be active only 
   on admission assessments, annual assessments, significant change assessments, 
   and significant correction (prior full) assessments.  These items will be 
   inactive and therefore missing on quarterly assessments, and more than half of 
   the assessments in the National Repository are quarterly assessments.  Please 
   consult the MDS data specifications to determine which items are active on which 
   record types.  Record type is defined by the values of AA8a (primary reason for 
   assessment) and AA8b (supplemental reason for assessment).
 
   NOTE:  State specific items (MDS Section S) are not available in the National 
   Repository.  In extract files from the National Repository, the Section S part 
   of the record will always be blank filler.
***/ 

TITLE "Read test520a.txt and save as SAS data set for RUG 5.20 testing";

/* Change path */
%let path = C:\Data\rug3\v5_20\testdata\;
LIBNAME rug520 "&path";
OPTIONS pageno=1;

/*The current code reads an MDS record text file (test520a.txt) and creates a SAS data set named 
      test520a.*/
DATA rug520.test520a;
   INFILE 'c:\data\rug3\v5_20\testdata\test520a.txt' LRECL=1812;

*****************************************************************************; 
***                                                                          ; 
***  SAS INPUT STATEMENT for MDS Extract File from MDS National Repository   ; 
***                                                                          ; 
*****************************************************************************; 
 
INPUT
         @1  REC_ID                          $CHAR2.
         @3  REC_TYPE                        $CHAR2.
         @5  AST_MOD_IND                     $CHAR1.
         @6  ORIG_ASMT_INT_ID                $CHAR10.
        @16  AST_CORR_VER                    $CHAR2.
        @18  CNT_FIL1                        $CHAR3.
        @21  P_REC_DT                        $CHAR8.  /* YYYYMMDD */
        @29  FC_DC_CD                        $CHAR8.
        @37  VCODE1                          $CHAR5.
        @42  VCODE2                          $CHAR5.
        @47  SFTW_ID                         $CHAR9.
        @56  SFT_VER                         $CHAR5.
        @61  FAC_ID                          $CHAR16.
        @77  RES_INT_ID                      $CHAR14.
        @91  AT1                             $CHAR2.
        @93  AT2                             $CHAR1.
        @94  AT3A                            $CHAR1.
        @95  AT3B                            $CHAR1.
        @96  AT3C                            $CHAR1.
        @97  AT3D                            $CHAR1.
        @98  AT3E                            $CHAR1.
        @99  AT4A                            $CHAR1.
       @100  AT4B                            $CHAR1.
       @101  AT4C                            $CHAR1.
       @102  AT4D                            $CHAR1.
       @103  AT5A                            $CHAR12.
       @115  AT5B                            $CHAR18.
       @133  AT6                             $CHAR8.  /* YYYYMMDD */
       @141  AT_SRC                          $CHAR1.
       @142  SUB_REQ                         $CHAR1.
       @143  CNT_FIL2                        $CHAR11.
       @154  AA1A                            $CHAR12.
       @166  AA1B                            $CHAR1.
       @167  AA1C                            $CHAR18.
       @185  AA1D                            $CHAR3.
       @188  AA2                             $CHAR1.
       @189  AA3                             $CHAR8.  /* YYYYMMDD */
       @197  AA4                             $CHAR1.
       @198  AA5A                            $CHAR9.
       @207  AA5B                            $CHAR12.
       @219  AA6A                            $CHAR15.
       @234  AA6B                            $CHAR12.
       @246  AA7                             $CHAR14.
       @260  AA8A                            $CHAR2.
       @262  AA8B                            $CHAR1.
       @263  AB1                             $CHAR8.  /* YYYYMMDD */
       @271  AB2                             $CHAR1.
       @272  AB3                             $CHAR1.
       @273  AB4                             $CHAR5.
       @278  AB5A                            $CHAR1.
       @279  AB5B                            $CHAR1.
       @280  AB5C                            $CHAR1.
       @281  AB5D                            $CHAR1.
       @282  AB5E                            $CHAR1.
       @283  AB5F                            $CHAR1.
       @284  AB6                             $CHAR21.
       @305  AB7                             $CHAR1.
       @306  AB8A                            $CHAR1.
       @307  AB8B                            $CHAR9.
       @316  AB9                             $CHAR1.
       @317  AB10A                           $CHAR1.
       @318  AB10B                           $CHAR1.
       @319  AB10C                           $CHAR1.
       @320  AB10D                           $CHAR1.
       @321  AB10E                           $CHAR1.
       @322  AB10F                           $CHAR1.
       @323  AB11                            $CHAR8.  /* YYYYMMDD */
       @331  AC1A                            $CHAR1.
       @332  AC1B                            $CHAR1.
       @333  AC1C                            $CHAR1.
       @334  AC1D                            $CHAR1.
       @335  AC1E                            $CHAR1.
       @336  AC1F                            $CHAR1.
       @337  AC1G                            $CHAR1.
       @338  AC1H                            $CHAR1.
       @339  AC1I                            $CHAR1.
       @340  AC1J                            $CHAR1.
       @341  AC1K                            $CHAR1.
       @342  AC1L                            $CHAR1.
       @343  AC1M                            $CHAR1.
       @344  AC1N                            $CHAR1.
       @345  AC1O                            $CHAR1.
       @346  AC1P                            $CHAR1.
       @347  AC1Q                            $CHAR1.
       @348  AC1R                            $CHAR1.
       @349  AC1S                            $CHAR1.
       @350  AC1T                            $CHAR1.
       @351  AC1U                            $CHAR1.
       @352  AC1V                            $CHAR1.
       @353  AC1W                            $CHAR1.
       @354  AC1X                            $CHAR1.
       @355  AC1Y                            $CHAR1.
       @356  A2                              $CHAR5.
       @361  A3A                             $CHAR8.  /* YYYYMMDD */
       @369  A3B                             $CHAR1.
       @370  A4A                             $CHAR8.  /* YYYYMMDD */
       @378  A4B                             $CHAR1.
       @379  A5                              $CHAR1.
       @380  A6                              $CHAR12.
       @392  A7A                             $CHAR1.
       @393  A7B                             $CHAR1.
       @394  A7C                             $CHAR1.
       @395  A7D                             $CHAR1.
       @396  A7E                             $CHAR1.
       @397  A7F                             $CHAR1.
       @398  A7G                             $CHAR1.
       @399  A7H                             $CHAR1.
       @400  A7I                             $CHAR1.
       @401  A7J                             $CHAR1.
       @402  A9A                             $CHAR1.
       @403  A9B                             $CHAR1.
       @404  A9C                             $CHAR1.
       @405  A9D                             $CHAR1.
       @406  A9E                             $CHAR1.
       @407  A9F                             $CHAR1.
       @408  A9G                             $CHAR1.
       @409  A10A                            $CHAR1.
       @410  A10B                            $CHAR1.
       @411  A10C                            $CHAR1.
       @412  A10D                            $CHAR1.
       @413  A10E                            $CHAR1.
       @414  A10F                            $CHAR1.
       @415  A10G                            $CHAR1.
       @416  A10H                            $CHAR1.
       @417  A10I                            $CHAR1.
       @418  B1                              $CHAR1.
       @419  B2A                             $CHAR1.
       @420  B2B                             $CHAR1.
       @421  B3A                             $CHAR1.
       @422  B3B                             $CHAR1.
       @423  B3C                             $CHAR1.
       @424  B3D                             $CHAR1.
       @425  B3E                             $CHAR1.
       @426  B4                              $CHAR1.
       @427  B5A                             $CHAR1.
       @428  B5B                             $CHAR1.
       @429  B5C                             $CHAR1.
       @430  B5D                             $CHAR1.
       @431  B5E                             $CHAR1.
       @432  B5F                             $CHAR1.
       @433  B6                              $CHAR1.
       @434  C1                              $CHAR1.
       @435  C2A                             $CHAR1.
       @436  C2B                             $CHAR1.
       @437  C2C                             $CHAR1.
       @438  C2D                             $CHAR1.
       @439  C3A                             $CHAR1.
       @440  C3B                             $CHAR1.
       @441  C3C                             $CHAR1.
       @442  C3D                             $CHAR1.
       @443  C3E                             $CHAR1.
       @444  C3F                             $CHAR1.
       @445  C3G                             $CHAR1.
       @446  C4                              $CHAR1.
       @447  C5                              $CHAR1.
       @448  C6                              $CHAR1.
       @449  C7                              $CHAR1.
       @450  D1                              $CHAR1.
       @451  D2A                             $CHAR1.
       @452  D2B                             $CHAR1.
       @453  D2C                             $CHAR1.
       @454  D3                              $CHAR1.
       @455  E1A                             $CHAR1.
       @456  E1B                             $CHAR1.
       @457  E1C                             $CHAR1.
       @458  E1D                             $CHAR1.
       @459  E1E                             $CHAR1.
       @460  E1F                             $CHAR1.
       @461  E1G                             $CHAR1.
       @462  E1H                             $CHAR1.
       @463  E1I                             $CHAR1.
       @464  E1J                             $CHAR1.
       @465  E1K                             $CHAR1.
       @466  E1L                             $CHAR1.
       @467  E1M                             $CHAR1.
       @468  E1N                             $CHAR1.
       @469  E1O                             $CHAR1.
       @470  E1P                             $CHAR1.
       @471  E2                              $CHAR1.
       @472  E3                              $CHAR1.
       @473  E4AA                            $CHAR1.
       @474  E4AB                            $CHAR1.
       @475  E4BA                            $CHAR1.
       @476  E4BB                            $CHAR1.
       @477  E4CA                            $CHAR1.
       @478  E4CB                            $CHAR1.
       @479  E4DA                            $CHAR1.
       @480  E4DB                            $CHAR1.
       @481  E4EA                            $CHAR1.
       @482  E4EB                            $CHAR1.
       @483  E5                              $CHAR1.
       @484  F1A                             $CHAR1.
       @485  F1B                             $CHAR1.
       @486  F1C                             $CHAR1.
       @487  F1D                             $CHAR1.
       @488  F1E                             $CHAR1.
       @489  F1F                             $CHAR1.
       @490  F1G                             $CHAR1.
       @491  F2A                             $CHAR1.
       @492  F2B                             $CHAR1.
       @493  F2C                             $CHAR1.
       @494  F2D                             $CHAR1.
       @495  F2E                             $CHAR1.
       @496  F2F                             $CHAR1.
       @497  F2G                             $CHAR1.
       @498  F2H                             $CHAR1.
       @499  F3A                             $CHAR1.
       @500  F3B                             $CHAR1.
       @501  F3C                             $CHAR1.
       @502  F3D                             $CHAR1.
       @503  G1AA                            $CHAR1.
       @504  G1AB                            $CHAR1.
       @505  G1BA                            $CHAR1.
       @506  G1BB                            $CHAR1.
       @507  G1CA                            $CHAR1.
       @508  G1CB                            $CHAR1.
       @509  G1DA                            $CHAR1.
       @510  G1DB                            $CHAR1.
       @511  G1EA                            $CHAR1.
       @512  G1EB                            $CHAR1.
       @513  G1FA                            $CHAR1.
       @514  G1FB                            $CHAR1.
       @515  G1GA                            $CHAR1.
       @516  G1GB                            $CHAR1.
       @517  G1HA                            $CHAR1.
       @518  G1HB                            $CHAR1.
       @519  G1IA                            $CHAR1.
       @520  G1IB                            $CHAR1.
       @521  G1JA                            $CHAR1.
       @522  G1JB                            $CHAR1.
       @523  G2A                             $CHAR1.
       @524  G2B                             $CHAR1.
       @525  G3A                             $CHAR1.
       @526  G3B                             $CHAR1.
       @527  G4AA                            $CHAR1.
       @528  G4AB                            $CHAR1.
       @529  G4BA                            $CHAR1.
       @530  G4BB                            $CHAR1.
       @531  G4CA                            $CHAR1.
       @532  G4CB                            $CHAR1.
       @533  G4DA                            $CHAR1.
       @534  G4DB                            $CHAR1.
       @535  G4EA                            $CHAR1.
       @536  G4EB                            $CHAR1.
       @537  G4FA                            $CHAR1.
       @538  G4FB                            $CHAR1.
       @539  G5A                             $CHAR1.
       @540  G5B                             $CHAR1.
       @541  G5C                             $CHAR1.
       @542  G5D                             $CHAR1.
       @543  G5E                             $CHAR1.
       @544  G6A                             $CHAR1.
       @545  G6B                             $CHAR1.
       @546  G6C                             $CHAR1.
       @547  G6D                             $CHAR1.
       @548  G6E                             $CHAR1.
       @549  G6F                             $CHAR1.
       @550  G7                              $CHAR1.
       @551  G8A                             $CHAR1.
       @552  G8B                             $CHAR1.
       @553  G8C                             $CHAR1.
       @554  G8D                             $CHAR1.
       @555  G8E                             $CHAR1.
       @556  G9                              $CHAR1.
       @557  H1A                             $CHAR1.
       @558  H1B                             $CHAR1.
       @559  H2A                             $CHAR1.
       @560  H2B                             $CHAR1.
       @561  H2C                             $CHAR1.
       @562  H2D                             $CHAR1.
       @563  H2E                             $CHAR1.
       @564  H3A                             $CHAR1.
       @565  H3B                             $CHAR1.
       @566  H3C                             $CHAR1.
       @567  H3D                             $CHAR1.
       @568  H3E                             $CHAR1.
       @569  H3F                             $CHAR1.
       @570  H3G                             $CHAR1.
       @571  H3H                             $CHAR1.
       @572  H3I                             $CHAR1.
       @573  H3J                             $CHAR1.
       @574  H4                              $CHAR1.
       @575  I1A                             $CHAR1.
       @576  I1B                             $CHAR1.
       @577  I1C                             $CHAR1.
       @578  I1D                             $CHAR1.
       @579  I1E                             $CHAR1.
       @580  I1F                             $CHAR1.
       @581  I1G                             $CHAR1.
       @582  I1H                             $CHAR1.
       @583  I1I                             $CHAR1.
       @584  I1J                             $CHAR1.
       @585  I1K                             $CHAR1.
       @586  I1L                             $CHAR1.
       @587  I1M                             $CHAR1.
       @588  I1N                             $CHAR1.
       @589  I1O                             $CHAR1.
       @590  I1P                             $CHAR1.
       @591  I1Q                             $CHAR1.
       @592  I1R                             $CHAR1.
       @593  I1S                             $CHAR1.
       @594  I1T                             $CHAR1.
       @595  I1U                             $CHAR1.
       @596  I1V                             $CHAR1.
       @597  I1W                             $CHAR1.
       @598  I1X                             $CHAR1.
       @599  I1Y                             $CHAR1.
       @600  I1Z                             $CHAR1.
       @601  I1AA                            $CHAR1.
       @602  I1BB                            $CHAR1.
       @603  I1CC                            $CHAR1.
       @604  I1DD                            $CHAR1.
       @605  I1EE                            $CHAR1.
       @606  I1FF                            $CHAR1.
       @607  I1GG                            $CHAR1.
       @608  I1HH                            $CHAR1.
       @609  I1II                            $CHAR1.
       @610  I1JJ                            $CHAR1.
       @611  I1KK                            $CHAR1.
       @612  I1LL                            $CHAR1.
       @613  I1MM                            $CHAR1.
       @614  I1NN                            $CHAR1.
       @615  I1OO                            $CHAR1.
       @616  I1PP                            $CHAR1.
       @617  I1QQ                            $CHAR1.
       @618  I1RR                            $CHAR1.
       @619  I2A                             $CHAR1.
       @620  I2B                             $CHAR1.
       @621  I2C                             $CHAR1.
       @622  I2D                             $CHAR1.
       @623  I2E                             $CHAR1.
       @624  I2F                             $CHAR1.
       @625  I2G                             $CHAR1.
       @626  I2H                             $CHAR1.
       @627  I2I                             $CHAR1.
       @628  I2J                             $CHAR1.
       @629  I2K                             $CHAR1.
       @630  I2L                             $CHAR1.
       @631  I2M                             $CHAR1.
       @632  I3A                             $CHAR7.  /* XX99.XX */
       @639  I3B                             $CHAR7.  /* XX99.XX */
       @646  I3C                             $CHAR7.  /* XX99.XX */
       @653  I3D                             $CHAR7.  /* XX99.XX */
       @660  I3E                             $CHAR7.  /* XX99.XX */
       @667  J1A                             $CHAR1.
       @668  J1B                             $CHAR1.
       @669  J1C                             $CHAR1.
       @670  J1D                             $CHAR1.
       @671  J1E                             $CHAR1.
       @672  J1F                             $CHAR1.
       @673  J1G                             $CHAR1.
       @674  J1H                             $CHAR1.
       @675  J1I                             $CHAR1.
       @676  J1J                             $CHAR1.
       @677  J1K                             $CHAR1.
       @678  J1L                             $CHAR1.
       @679  J1M                             $CHAR1.
       @680  J1N                             $CHAR1.
       @681  J1O                             $CHAR1.
       @682  J1P                             $CHAR1.
       @683  J2A                             $CHAR1.
       @684  J2B                             $CHAR1.
       @685  J3A                             $CHAR1.
       @686  J3B                             $CHAR1.
       @687  J3C                             $CHAR1.
       @688  J3D                             $CHAR1.
       @689  J3E                             $CHAR1.
       @690  J3F                             $CHAR1.
       @691  J3G                             $CHAR1.
       @692  J3H                             $CHAR1.
       @693  J3I                             $CHAR1.
       @694  J3J                             $CHAR1.
       @695  J4A                             $CHAR1.
       @696  J4B                             $CHAR1.
       @697  J4C                             $CHAR1.
       @698  J4D                             $CHAR1.
       @699  J4E                             $CHAR1.
       @700  J5A                             $CHAR1.
       @701  J5B                             $CHAR1.
       @702  J5C                             $CHAR1.
       @703  J5D                             $CHAR1.
       @704  K1A                             $CHAR1.
       @705  K1B                             $CHAR1.
       @706  K1C                             $CHAR1.
       @707  K1D                             $CHAR1.
       @708  K2A                             $CHAR2.
       @710  K2B                             $CHAR3.
       @713  K3A                             $CHAR1.
       @714  K3B                             $CHAR1.
       @715  K4A                             $CHAR1.
       @716  K4B                             $CHAR1.
       @717  K4C                             $CHAR1.
       @718  K4D                             $CHAR1.
       @719  K5A                             $CHAR1.
       @720  K5B                             $CHAR1.
       @721  K5C                             $CHAR1.
       @722  K5D                             $CHAR1.
       @723  K5E                             $CHAR1.
       @724  K5F                             $CHAR1.
       @725  K5G                             $CHAR1.
       @726  K5H                             $CHAR1.
       @727  K5I                             $CHAR1.
       @728  K6A                             $CHAR1.
       @729  K6B                             $CHAR1.
       @730  L1A                             $CHAR1.
       @731  L1B                             $CHAR1.
       @732  L1C                             $CHAR1.
       @733  L1D                             $CHAR1.
       @734  L1E                             $CHAR1.
       @735  L1F                             $CHAR1.
       @736  L1G                             $CHAR1.
       @737  M1A                             $CHAR1.
       @738  M1B                             $CHAR1.
       @739  M1C                             $CHAR1.
       @740  M1D                             $CHAR1.
       @741  M2A                             $CHAR1.
       @742  M2B                             $CHAR1.
       @743  M3                              $CHAR1.
       @744  M4A                             $CHAR1.
       @745  M4B                             $CHAR1.
       @746  M4C                             $CHAR1.
       @747  M4D                             $CHAR1.
       @748  M4E                             $CHAR1.
       @749  M4F                             $CHAR1.
       @750  M4G                             $CHAR1.
       @751  M4H                             $CHAR1.
       @752  M5A                             $CHAR1.
       @753  M5B                             $CHAR1.
       @754  M5C                             $CHAR1.
       @755  M5D                             $CHAR1.
       @756  M5E                             $CHAR1.
       @757  M5F                             $CHAR1.
       @758  M5G                             $CHAR1.
       @759  M5H                             $CHAR1.
       @760  M5I                             $CHAR1.
       @761  M5J                             $CHAR1.
       @762  M6A                             $CHAR1.
       @763  M6B                             $CHAR1.
       @764  M6C                             $CHAR1.
       @765  M6D                             $CHAR1.
       @766  M6E                             $CHAR1.
       @767  M6F                             $CHAR1.
       @768  M6G                             $CHAR1.
       @769  N1A                             $CHAR1.
       @770  N1B                             $CHAR1.
       @771  N1C                             $CHAR1.
       @772  N1D                             $CHAR1.
       @773  N2                              $CHAR1.
       @774  N3A                             $CHAR1.
       @775  N3B                             $CHAR1.
       @776  N3C                             $CHAR1.
       @777  N3D                             $CHAR1.
       @778  N3E                             $CHAR1.
       @779  N4A                             $CHAR1.
       @780  N4B                             $CHAR1.
       @781  N4C                             $CHAR1.
       @782  N4D                             $CHAR1.
       @783  N4E                             $CHAR1.
       @784  N4F                             $CHAR1.
       @785  N4G                             $CHAR1.
       @786  N4H                             $CHAR1.
       @787  N4I                             $CHAR1.
       @788  N4J                             $CHAR1.
       @789  N4K                             $CHAR1.
       @790  N4L                             $CHAR1.
       @791  N4M                             $CHAR1.
       @792  N5A                             $CHAR1.
       @793  N5B                             $CHAR1.
       @794  O1                              $CHAR2.
       @796  O2                              $CHAR1.
       @797  O3                              $CHAR1.
       @798  O4A                             $CHAR1.
       @799  O4B                             $CHAR1.
       @800  O4C                             $CHAR1.
       @801  O4D                             $CHAR1.
       @802  O4E                             $CHAR1.
       @803  P1AA                            $CHAR1.
       @804  P1AB                            $CHAR1.
       @805  P1AC                            $CHAR1.
       @806  P1AD                            $CHAR1.
       @807  P1AE                            $CHAR1.
       @808  P1AF                            $CHAR1.
       @809  P1AG                            $CHAR1.
       @810  P1AH                            $CHAR1.
       @811  P1AI                            $CHAR1.
       @812  P1AJ                            $CHAR1.
       @813  P1AK                            $CHAR1.
       @814  P1AL                            $CHAR1.
       @815  P1AM                            $CHAR1.
       @816  P1AN                            $CHAR1.
       @817  P1AO                            $CHAR1.
       @818  P1AP                            $CHAR1.
       @819  P1AQ                            $CHAR1.
       @820  P1AR                            $CHAR1.
       @821  P1AS                            $CHAR1.
       @822  P1BAA                           $CHAR1.
       @823  P1BAB                           $CHAR4.
       @827  P1BBA                           $CHAR1.
       @828  P1BBB                           $CHAR4.
       @832  P1BCA                           $CHAR1.
       @833  P1BCB                           $CHAR4.
       @837  P1BDA                           $CHAR1.
       @838  P1BDB                           $CHAR4.
       @842  P1BEA                           $CHAR1.
       @843  P1BEB                           $CHAR4.
       @847  P2A                             $CHAR1.
       @848  P2B                             $CHAR1.
       @849  P2C                             $CHAR1.
       @850  P2D                             $CHAR1.
       @851  P2E                             $CHAR1.
       @852  P2F                             $CHAR1.
       @853  P3A                             $CHAR1.
       @854  P3B                             $CHAR1.
       @855  P3C                             $CHAR1.
       @856  P3D                             $CHAR1.
       @857  P3E                             $CHAR1.
       @858  P3F                             $CHAR1.
       @859  P3G                             $CHAR1.
       @860  P3H                             $CHAR1.
       @861  P3I                             $CHAR1.
       @862  P3J                             $CHAR1.
       @863  P3K                             $CHAR1.
       @864  P4A                             $CHAR1.
       @865  P4B                             $CHAR1.
       @866  P4C                             $CHAR1.
       @867  P4D                             $CHAR1.
       @868  P4E                             $CHAR1.
       @869  P5                              $CHAR2.
       @871  P6                              $CHAR2.
       @873  P7                              $CHAR2.
       @875  P8                              $CHAR2.
       @877  P9                              $CHAR1.
       @878  Q1A                             $CHAR1.
       @879  Q1B                             $CHAR1.
       @880  Q1C                             $CHAR1.
       @881  Q2                              $CHAR1.
       @882  R1A                             $CHAR1.
       @883  R1B                             $CHAR1.
       @884  R1C                             $CHAR1.
       @885  R2B                             $CHAR8.  /* YYYYMMDD */
       @893  R3A                             $CHAR1.
       @894  R3B                             $CHAR1.
       @895  R4                              $CHAR8.  /* YYYYMMDD */
       @903  S_FILL1                         $CHAR100.
      @1003  S_FILL2                         $CHAR100.
      @1103  S_FILL3                         $CHAR100.
      @1203  T1AA                            $CHAR1.
      @1204  T1AB                            $CHAR4.
      @1208  T1B                             $CHAR1.
      @1209  T1C                             $CHAR2.
      @1211  T1D                             $CHAR4.
      @1215  T2A                             $CHAR1.
      @1216  T2B                             $CHAR1.
      @1217  T2C                             $CHAR1.
      @1218  T2D                             $CHAR1.
      @1219  T2E                             $CHAR1.
      @1220  T3MCARE                         $CHAR5.
      @1225  T3STATE                         $CHAR5.
      @1230  RUG34_HR                        $CHAR3.
      @1233  RUG34_MX                        $CHAR3.
      @1236  RUG34_CMI_HR                    $CHAR10.  /*s9999.999*/
      @1246  RUG34_CMI_MX                    $CHAR10.  /*s9999.999*/
      @1256  RUG34_CMI_SET                   $CHAR3.
      @1259  RUG34_VERSION                   $CHAR2.
      @1261  RUG44_HR                        $CHAR3.
      @1264  RUG44_MX                        $CHAR3.
      @1267  RUG44_CMI_HR                    $CHAR10.  /*s9999.999*/
      @1277  RUG44_CMI_MX                    $CHAR10.  /*s9999.999*/
      @1287  RUG44_CMI_SET                   $CHAR3.
      @1290  RUG44_VERSION                   $CHAR2.
      @1292  RUG53_HR                        $CHAR3.
      @1295  RUG53_MX                        $CHAR3.
      @1298  RUG53_CMI_HR                    $CHAR10.  /*s9999.999*/
      @1308  RUG53_CMI_MX                    $CHAR10.  /*s9999.999*/
      @1318  RUG53_CMI_SET                   $CHAR3.
      @1321  RUG53_VERSION                   $CHAR2.
      @1323  ADLSUM                          $CHAR2.
      @1325  CPSSUM                          $CHAR1.
      @1336  FILLER                          $CHAR254.
      @1590  VA01A                           $CHAR1.
      @1591  VA01B                           $CHAR1.
      @1592  VA02A                           $CHAR1.
      @1593  VA02B                           $CHAR1.
      @1594  VA03A                           $CHAR1.
      @1595  VA03B                           $CHAR1.
      @1596  VA04A                           $CHAR1.
      @1597  VA04B                           $CHAR1.
      @1598  VA05A                           $CHAR1.
      @1599  VA05B                           $CHAR1.
      @1600  VA06A                           $CHAR1.
      @1601  VA06B                           $CHAR1.
      @1602  VA07A                           $CHAR1.
      @1603  VA07B                           $CHAR1.
      @1604  VA08A                           $CHAR1.
      @1605  VA08B                           $CHAR1.
      @1606  VA09A                           $CHAR1.
      @1607  VA09B                           $CHAR1.
      @1608  VA10A                           $CHAR1.
      @1609  VA10B                           $CHAR1.
      @1610  VA11A                           $CHAR1.
      @1611  VA11B                           $CHAR1.
      @1612  VA12A                           $CHAR1.
      @1613  VA12B                           $CHAR1.
      @1614  VA13A                           $CHAR1.
      @1615  VA13B                           $CHAR1.
      @1616  VA14A                           $CHAR1.
      @1617  VA14B                           $CHAR1.
      @1618  VA15A                           $CHAR1.
      @1619  VA15B                           $CHAR1.
      @1620  VA16A                           $CHAR1.
      @1621  VA16B                           $CHAR1.
      @1622  VA17A                           $CHAR1.
      @1623  VA17B                           $CHAR1.
      @1624  VA18A                           $CHAR1.
      @1625  VA18B                           $CHAR1.
      @1626  VA_FILL                         $CHAR18.
      @1644  MDS_ASMT_INT_ID                 $CHAR10.
      @1654  AST_BEG_VER_DT                  $CHAR8.  /* YYYYMMDD (ALSO SUBMISION DATE) */
      @1662  AST_END_VER_DT                  $CHAR8.  /* YYYYMMDD */
      @1670  VB2_RAP_DT                      $CHAR8.  /* YYYYMMDD */
      @1678  VB4_CARE_PLAN_DT                $CHAR8.  /* YYYYMMDD */
      @1686  PRIOR_ID                        $CHAR68.
      @1754  TARGET_DATE                     $CHAR8.  /* YYYYMMDD */
      @1762  HCFAOTHR                        $CHAR6.
      @1768  ST_CODE                         $CHAR2.
      @1770  FAC_INT_ID                      $CHAR10.
      @1780  MCR_SET_CODE                    $CHAR3.
      @1783  MCD_SET_CODE                    $CHAR3.
      @1786  MCR_GP                          $CHAR3.
      @1789  MCR_VR                          $CHAR2.
      @1791  MCR_CMI                         $CHAR7.  /* XXX.XXXX */
      @1798  MCD_GP                          $CHAR3.
      @1801  MCD_VR                          $CHAR2.
      @1803  MCD_CMI                         $CHAR7.  /* XXX.XXXX */
      @1810  FILLER2                         $CHAR2.
      @1812  DATA_END                        $CHAR1.
;
 
 
 
***************************************************************;
***                                                            ;
***   SAS LABEL Statement Follows                              ;
***                                                            ;
***************************************************************;
 
LABEL
     REC_ID                         = 'RECORD ID'
     REC_TYPE                       = 'RECORD TYPE CODE'
     AST_MOD_IND                    = 'Rec Status (C)urr vs Hist (X,M)'
     ORIG_ASMT_INT_ID               = 'Rec ID-Original Record'
     AST_CORR_VER                   = 'Corr Version Seq Num'
     CNT_FIL1                       = 'Filler 1'
     P_REC_DT                       = 'PREVIOUS RECORD DATE'
     FC_DC_CD                       = 'DOCUMENT ID CODE (FACILITY USE)'
     VCODE1                         = 'MDS VERSION COMPLETED CODE'
     VCODE2                         = 'MDS DATA SPECS VERSION CODE'
     SFTW_ID                        = 'SOFTWARE VENDOR OR AGENT TAX ID'
     SFT_VER                        = 'SOFTWARE VERSION'
     RES_INT_ID                     = 'STATE ASSIGNED UNIQUE RES ID'
     AT1                            = 'Attestation Sequence Number  FUTURE'
     AT2                            = 'Action Requested'
     AT3A                           = 'Reason for mod: Transcript error'
     AT3B                           = 'Reason for mod: Data entry error'
     AT3C                           = 'Reason for mod: Sftware prod error'
     AT3D                           = 'Reason for mod: Item coding err'
     AT3E                           = 'Reason for mod: Other err'
     AT4A                           = 'Reason for inact: Test as productn'
     AT4B                           = 'Reason for inact: Event didnt occur'
     AT4C                           = 'Reason for inact: Submt inapprpt'
     AT4D                           = 'Reason for inact: Othr inact reason'
     AT5A                           = 'Attestng Individual: First name'
     AT5B                           = 'Attestng Individual: Last name'
     AT6                            = 'Attestation date             FUTURE'
     AT_SRC                         = 'FUTURE'
     SUB_REQ                        = 'Reqmnt for submiting MDS record'
     CNT_FIL2                       = 'Filler 2'
     AA1A                           = 'Resident First Name'
     AA1B                           = 'Resident Middle Initial'
     AA1C                           = 'Resident Last Name'
     AA1D                           = 'Resident Name Suffix'
     AA2                            = 'Gender'
     AA3                            = 'Birthdate'
     AA4                            = 'Race/Ethnicity'
     AA5A                           = 'Social Security Number'
     AA5B                           = 'Medicare (or comp) number'
     AA6A                           = 'Facility State Provider No.'
     AA6B                           = 'Facility Federal Provider No.'
     AA7                            = 'Medicaid No.'
     AA8A                           = 'Primary Reason For Assessment'
     AA8B                           = 'Special Reason for Assessment'
     AB1                            = 'Date of Entry'
     AB2                            = 'Admitted from (at Entry)'
     AB3                            = 'Lived Alone (Prior to Entry)'
     AB4                            = 'Zip Code of Prior Primary Resid'
     AB5A                           = 'History: Prior stay at this NH'
     AB5B                           = 'History: Stay in other NH'
     AB5C                           = 'History: Other residential fac'
     AB5D                           = 'History: MH/psychiatric setting'
     AB5E                           = 'History: MR/DD setting'
     AB5F                           = 'History: None of Above'
     AB6                            = 'Lifetime Occupation(s)'
     AB7                            = 'Education (Highest Level Compl)'
     AB8A                           = 'Primary Language'
     AB8B                           = 'If other (language), specify'
     AB9                            = 'Mental Health History'
     AB10A                          = 'No MR/DD--Not applicable'
     AB10B                          = 'Downs syndrome'
     AB10C                          = 'Autism'
     AB10D                          = 'Epilepsy'
     AB10E                          = 'Other organic condition MR/DD'
     AB10F                          = 'MR/DD with no organic condition'
     AB11                           = 'Date Background Info Completed'
     AC1A                           = 'Stays up late at night'
     AC1B                           = 'Naps regularly during day'
     AC1C                           = 'Goes out 1+ days a week'
     AC1D                           = 'Stays busy w/ hobby/fixed routn'
     AC1E                           = 'Spends most time alone or TV'
     AC1F                           = 'Moves independently indoors'
     AC1G                           = 'Use of tobacco daily'
     AC1H                           = 'None of Above'
     AC1I                           = 'Distinct food preferences'
     AC1J                           = 'Eats between meals most days'
     AC1K                           = 'Use of alcohol/weekly'
     AC1L                           = 'None of Above'
     AC1M                           = 'In bedclothes much of day'
     AC1N                           = 'Wakens to toilet most nights'
     AC1O                           = 'Has irregular BM pattern'
     AC1P                           = 'Showers for bathing'
     AC1Q                           = 'Bathing in PM'
     AC1R                           = 'None of Above'
     AC1S                           = 'Daily contact w/ reltiv/friends'
     AC1T                           = 'Usually attends church, temple,'
     AC1U                           = 'Finds strength in faith'
     AC1V                           = 'Daily animal companion'
     AC1W                           = 'Involved in group activities'
     AC1X                           = 'None of Above'
     AC1Y                           = 'Unknown customary routine'
     A2                             = 'Room Number'
     A3A                            = 'Assessment Reference Date'
     A3B                            = 'Filler'
     A4A                            = 'Date of Reentry'
     A4B                            = 'Admitted from (at Reentry)'
     A5                             = 'Marital Status'
     A6                             = 'Medical Record No.'
     A7A                            = 'Pmt: Medicaid per diem'
     A7B                            = 'Pyt: Medicare per diem'
     A7C                            = 'Pmt: Medicare ancil part A'
     A7D                            = 'Pmt: Medicare ancil part A'
     A7E                            = 'Pmt: CHAMPUS per diem'
     A7F                            = 'Pmt: VA per diem'
     A7G                            = 'Pmt: Self/fam pays per diem'
     A7H                            = 'Pmt: Mcaid res liabil/Mcare cop'
     A7I                            = 'Pmt: Private insurance per diem'
     A7J                            = 'Pmt: Other per diem'
     A9A                            = 'Rspnsblty: Legal guardian'
     A9B                            = 'Rspnsblty: Other legal ovesight'
     A9C                            = 'Rspnsblty: Durabl pwr atty/hlth'
     A9D                            = 'Rspnsblty: Durabl pwr atty/fin'
     A9E                            = 'Rspnsblty: Family mbr responsbl'
     A9F                            = 'Rspnsblty: Patient respons'
     A9G                            = 'Rspnsblty: None of Above'
     A10A                           = 'Adv. Dir: Living will'
     A10B                           = 'Adv. Dir: Do not resuscitate'
     A10C                           = 'Adv. Dir: Do not hospitalize'
     A10D                           = 'Adv. Dir: Organ donation'
     A10E                           = 'Adv. Dir: Autopsy request'
     A10F                           = 'Adv. Dir: Feeding restrictions'
     A10G                           = 'Adv. Dir: Medication restrictns'
     A10H                           = 'Adv. Dir: Othr trtmnt restrctns'
     A10I                           = 'Adv. Dir: None of Above'
     B1                             = 'Comatose'
     B2A                            = 'Short-term memory OK'
     B2B                            = 'Long-term memory OK'
     B3A                            = 'Mem/Recall: Current season'
     B3B                            = 'Mem/Recall: Location of own rm'
     B3C                            = 'Mem/Recall: Staff names/faces'
     B3D                            = 'Mem/Recall: That he/she in NH'
     B3E                            = 'Mem/Recall: None of Above'
     B4                             = 'Cognitive Skills/Daily Decision'
     B5A                            = 'Easily distracted'
     B5B                            = 'Periods altered prcption/awrnes'
     B5C                            = 'Episodes of disorganized speech'
     B5D                            = 'Periods of restlessness'
     B5E                            = 'Periods of lethargy'
     B5F                            = 'Mental function var during day'
     B6                             = 'Change in Cognitive Status'
     C1                             = 'Hearing'
     C2A                            = 'Hearing aid prsnt/used'
     C2B                            = 'Hearing aid prsnt/not used regl'
     C2C                            = 'Other receptive comm tchnq used'
     C2D                            = 'Comm Devices: None of Above'
     C3A                            = 'Mode Expres: Speech'
     C3B                            = 'Mode Expres: Writing msgs'
     C3C                            = 'Mode Expres: Amer. Sign/Braill'
     C3D                            = 'Mode Expres: Signs/gest/sounds'
     C3E                            = 'Mode Expres: Communic board'
     C3F                            = 'Mode Expres: Other'
     C3G                            = 'Mode Expres: None of Above'
     C4                             = 'Making Self Understood'
     C5                             = 'Speech Clarity'
     C6                             = 'Ability to Understand Others'
     C7                             = 'Change in Communication/Hearing'
     D1                             = 'Vision'
     D2A                            = 'Side vision problems'
     D2B                            = 'Sees halos/rings/flash/curtains'
     D2C                            = 'Visual Limitation: None ofAbove'
     D3                             = 'Visual Appliances'
     E1A                            = 'Negative statements'
     E1B                            = 'Repetitive questions'
     E1C                            = 'Repetitive verbalizations'
     E1D                            = 'Persistent anger with self/othe'
     E1E                            = 'Self deprecation'
     E1F                            = 'Expression of unrealistic fears'
     E1G                            = 'Recurrent stmts of terrible fut'
     E1H                            = 'Repetitive health complaints'
     E1I                            = 'Repetitive anxious complaints/c'
     E1J                            = 'Unpleasant mood in morning'
     E1K                            = 'Insomnia/chg in sleeping patrn'
     E1L                            = 'Sad/pained/worried facial exprs'
     E1M                            = 'Crying/tearfulness'
     E1N                            = 'Repetitive physical movements'
     E1O                            = 'Withdrawal fm activ of iterest'
     E1P                            = 'Reduced social interaction'
     E2                             = 'Mood Persistence'
     E3                             = 'Change in Mood'
     E4AA                           = 'Wandering: Frequency'
     E4AB                           = 'Wandering: Alterability'
     E4BA                           = 'Verbaly abusv behvr:Frequency'
     E4BB                           = 'Verbaly abusv behvr:Alterablty'
     E4CA                           = 'Physcly abusv behvr:Frequency'
     E4CB                           = 'Physcly abusv behvr:Alterablty'
     E4DA                           = 'Soc Inpr/dsrpt behvr:Frequency'
     E4DB                           = 'Soc Inpr/dsrpt behvr:Alterablty'
     E4EA                           = 'Resists Care: Frequency'
     E4EB                           = 'Resists Care: Alterability'
     E5                             = 'Change in Behavioral Symptoms'
     F1A                            = 'At ease interacting with others'
     F1B                            = 'At ease doing pland/strct activ'
     F1C                            = 'At ease doing self-init activ'
     F1D                            = 'Establishes own goals'
     F1E                            = 'Pursue involvmnt in life of fac'
     F1F                            = 'Accepts invite to most grp actv'
     F1G                            = 'Sense of Initiative: None of Ab'
     F2A                            = 'Covert/open conflict with staff'
     F2B                            = 'Unhappy with roommate'
     F2C                            = 'Unhappy with other residents'
     F2D                            = 'Open conflict/anger with family'
     F2E                            = 'Absence of contact with family/'
     F2F                            = 'Recent loss family/friend'
     F2G                            = 'Does not easily adjust to routi'
     F2H                            = 'Unsettled Relationships: None o'
     F3A                            = 'Strong identification with past'
     F3B                            = 'Sadness/anger over lost roles/s'
     F3C                            = 'Perceives daily routine very di'
     F3D                            = 'Past Roles: None of Above'
     G1AA                           = 'Bed mobility: Self-Performance'
     G1AB                           = 'Bed mobility: Support Provided'
     G1BA                           = 'Transfer: Self-Performance'
     G1BB                           = 'Transfer: Support Provided'
     G1CA                           = 'Walk in room: Self-Perform'
     G1CB                           = 'Walk in room: Support Provid'
     G1DA                           = 'Walk corridor: Self-Perform'
     G1DB                           = 'Walk corridor: Support Provid'
     G1EA                           = 'Locomo on unit: Self-Perform'
     G1EB                           = 'Locomo on unit: Support Provid'
     G1FA                           = 'Locomo off unit: Self-Perfom'
     G1FB                           = 'Locomo off unit: Support Provid'
     G1GA                           = 'Dressing: Self-Perform'
     G1GB                           = 'Dressing: Support Provid'
     G1HA                           = 'Eating: Self-Perform'
     G1HB                           = 'Eating: Support Provid'
     G1IA                           = 'Toilet use: Self-Perform'
     G1IB                           = 'Toilet use: Support Provid'
     G1JA                           = 'Persnl hygiene: Self-Perform'
     G1JB                           = 'Persnl hygiene: Support Provid'
     G2A                            = 'Bathing: Self-Perform'
     G2B                            = 'Bathing: Support Provid'
     G3A                            = 'Balance while standing'
     G3B                            = 'Balance while sitting'
     G4AA                           = 'Neck: Range of motion'
     G4AB                           = 'Neck: Voluntary movement'
     G4BA                           = 'Arm: Range of motion'
     G4BB                           = 'Arm:  Voluntary movement'
     G4CA                           = 'Hand: Range of motion'
     G4CB                           = 'Hand:  Voluntary movement'
     G4DA                           = 'Leg: Range of motion'
     G4DB                           = 'Leg: Voluntary movement'
     G4EA                           = 'Foot: Range of motion'
     G4EB                           = 'Foot:  Voluntary movement'
     G4FA                           = 'Other: Range of motion'
     G4FB                           = 'Other: Voluntary movement'
     G5A                            = 'Cane/walker/crutch'
     G5B                            = 'Wheeled self'
     G5C                            = 'Other person wheeled'
     G5D                            = 'Wheelchair for primary locomo'
     G5E                            = 'Modes of Locomo: None of Above'
     G6A                            = 'Bedfast all or most of the time'
     G6B                            = 'Bed rails for bed moblty/trnsfr'
     G6C                            = 'Lifted manually'
     G6D                            = 'Lifted mechanically'
     G6E                            = 'Transfer aid'
     G6F                            = 'Modes Transfer: None of Above'
     G7                             = 'Task Segmentation'
     G8A                            = 'Resident sees incr indepn capbl'
     G8B                            = 'Staff sees incr indepn capbl'
     G8C                            = 'Residnt slow perform tasks/actv'
     G8D                            = 'Morning to evening diff in ADL'
     G8E                            = 'ADL Rehab Potntl: None of Above'
     G9                             = 'Change in ADL Function'
     H1A                            = 'Bowel continence'
     H1B                            = 'Bladder continence'
     H2A                            = 'Bowel elim pattern regular'
     H2B                            = 'Constipation'
     H2C                            = 'Diarrhea'
     H2D                            = 'Fecal impaction'
     H2E                            = 'Bowel Elim Pattern: None Above'
     H3A                            = 'Any scheduled toileting plan'
     H3B                            = 'Bladder retraining program'
     H3C                            = 'External (condom) catheter'
     H3D                            = 'Indwelling catheter'
     H3E                            = 'Intermittent catheter'
     H3F                            = 'Did not use toilt/commode/urinl'
     H3G                            = 'Pads/briefs used'
     H3H                            = 'Enemas/irrigation'
     H3I                            = 'Ostomy present'
     H3J                            = 'Contnce Appl Progr: None Above'
     H4                             = 'Change in Urinary Continence'
     I1A                            = 'Diabetes mellitus'
     I1B                            = 'Hyperthyroidism'
     I1C                            = 'Hypothyroidism'
     I1D                            = 'Arteriosclrtic heart dis (ASHD)'
     I1E                            = 'Cardiac dysrhythmias'
     I1F                            = 'Congestive heart failure'
     I1G                            = 'Deep vein thrombosis'
     I1H                            = 'Hypertension'
     I1I                            = 'Hypotension'
     I1J                            = 'Peripheral vascular disease'
     I1K                            = 'Other cardiovascular disease'
     I1L                            = 'Arthritis'
     I1M                            = 'Hip fracture'
     I1N                            = 'Missing limb'
     I1O                            = 'Osteoporosis'
     I1P                            = 'Pathological bone fracture'
     I1Q                            = 'Alzheimers disease'
     I1R                            = 'Aphasia'
     I1S                            = 'Cerebral palsy'
     I1T                            = 'Cerebrovascular acidnt (stroke)'
     I1U                            = 'Dementia other than Alzheimers'
     I1V                            = 'Hemiplegia/hemiparesis'
     I1W                            = 'Multiple sclerosis'
     I1X                            = 'Paraplegia'
     I1Y                            = 'Parkinsons disease'
     I1Z                            = 'Quadriplegia'
     I1AA                           = 'Seizure disorder'
     I1BB                           = 'Transient ischemic attack (TIA)'
     I1CC                           = 'Traumatic brain injury'
     I1DD                           = 'Anxiety disorder'
     I1EE                           = 'Depression'
     I1FF                           = 'Manic depressive (bipolar dis)'
     I1GG                           = 'Schizophrenia'
     I1HH                           = 'Asthma'
     I1II                           = 'Emphysema/COPD'
     I1JJ                           = 'Cataracts'
     I1KK                           = 'Diabetic retinopathy'
     I1LL                           = 'Glaucoma'
     I1MM                           = 'Macular degeneration'
     I1NN                           = 'Allergies'
     I1OO                           = 'Anemia'
     I1PP                           = 'Cancer'
     I1QQ                           = 'Renal failure'
     I1RR                           = 'Diseases: None of Above'
     I2A                            = 'Antibiotic resistant infection'
     I2B                            = 'Clostridium difficile (c. diff.'
     I2C                            = 'Conjunctivitis'
     I2D                            = 'HIV infection'
     I2E                            = 'Pneumonia'
     I2F                            = 'Respiratory infection'
     I2G                            = 'Septicemia'
     I2H                            = 'Sexually transmitted diseases'
     I2I                            = 'Tuberculosis'
     I2J                            = 'UTI in last 30 days'
     I2K                            = 'Viral hepatitis'
     I2L                            = 'Wound infection'
     I2M                            = 'Infections: None of Above'
     I3A                            = 'a. Other diagnosis and ICD9'
     I3B                            = 'b. Other diagnosis and ICD9'
     I3C                            = 'c. Other diagnosis and ICD9'
     I3D                            = 'd. Other diagnosis and ICD9'
     I3E                            = 'e. Other diagnosis and ICD9'
     J1A                            = 'Weight fluct 3+ lbs. in 7 days'
     J1B                            = 'Inabl lie flat--shrtnes breath'
     J1C                            = 'Dehydratd--output exceeds input'
     J1D                            = 'Insufficnt fluid in last 3 days'
     J1E                            = 'Delusions'
     J1F                            = 'Dizziness/vertigo'
     J1G                            = 'Edema'
     J1H                            = 'Fever'
     J1I                            = 'Hallucinations'
     J1J                            = 'Internal bleeding'
     J1K                            = 'Recur lung aspir in lst 90 days'
     J1L                            = 'Shortness of breath'
     J1M                            = 'Syncope (fainting)'
     J1N                            = 'Unsteady gait'
     J1O                            = 'Vomiting'
     J1P                            = 'Problem Condtns: None of Above'
     J2A                            = 'Pain Frequency'
     J2B                            = 'Pain Intensity'
     J3A                            = 'Back pain'
     J3B                            = 'Bone pain'
     J3C                            = 'Chest pain durng usual activitv'
     J3D                            = 'Headache'
     J3E                            = 'Hip pain'
     J3F                            = 'Incisional pain'
     J3G                            = 'Joint pain (other than hip)'
     J3H                            = 'Soft tissue pain (lesion)'
     J3I                            = 'Stomach pain'
     J3J                            = 'Other pain'
     J4A                            = 'Fell in past 30 days'
     J4B                            = 'Fell in past 31-180 days'
     J4C                            = 'Hip fracture in last 180 days'
     J4D                            = 'Other fracture in last 180 days'
     J4E                            = 'Accidents: None of Above'
     J5A                            = 'Cond/diseses lead to instablty'
     J5B                            = 'Res exper acute episod/flare-up'
     J5C                            = 'End-stage dis, 6 or< mo to Live'
     J5D                            = 'Stabil of Condit: None of Above'
     K1A                            = 'Chewing problem'
     K1B                            = 'Swallowing problem'
     K1C                            = 'Mouth pain'
     K1D                            = 'Oral Problems: None of Above'
     K2A                            = 'Height (inches)'
     K2B                            = 'Weight (pounds)'
     K3A                            = 'Weight loss'
     K3B                            = 'Weight gain'
     K4A                            = 'Complain about taste many foods'
     K4B                            = 'Regular complaints of hunger'
     K4C                            = 'Leave 25%+ food uneat most meal'
     K4D                            = 'Nutritional Problms: None Above'
     K5A                            = 'Parenteral IV'
     K5B                            = 'Feeding tube'
     K5C                            = 'Mechanically altered diet'
     K5D                            = 'Syringe (oral feeding)'
     K5E                            = 'Therapeutic diet'
     K5F                            = 'Dietary supplement between meal'
     K5G                            = 'Plate guard, stabilized utensil'
     K5H                            = 'On planned weight change progrm'
     K5I                            = 'Nutritionl Approach: None Above'
     K6A                            = 'Totl calor % recvd last 7 days'
     K6B                            = 'Ave fluid intk daily lst 7 days'
     L1A                            = 'Debris in mouth before bed'
     L1B                            = 'Has dentures or removble bridge'
     L1C                            = 'Some/all natural teeth lost'
     L1D                            = 'Broken, loose, or carious teeth'
     L1E                            = 'Inflamed/bleed gums, oral abscs'
     L1F                            = 'Daly clean teth/dent, mouth car'
     L1G                            = 'Oral Stat/Dis Prevnt:None Above'
     M1A                            = 'Ulcers: Stage 1'
     M1B                            = 'Ulcers: Stage 2'
     M1C                            = 'Ulcers: Stage 3'
     M1D                            = 'Ulcers: Stage 4'
     M2A                            = 'Pressure ulcer'
     M2B                            = 'Stasis ulcer'
     M3                             = 'History of resolved ulcers'
     M4A                            = 'Abrasions, bruises'
     M4B                            = 'Burns (second or third degree)'
     M4C                            = 'Open lesions other than ulcers,'
     M4D                            = 'Rashes--eg, intertrigo, eczema'
     M4E                            = 'Skin desenstizd to pain, presur'
     M4F                            = 'Skin tears, cuts (not surgery)'
     M4G                            = 'Surgical wounds'
     M4H                            = 'Other Skin Problems: None Above'
     M5A                            = 'Press relievng device for chair'
     M5B                            = 'Press relievng device for bed'
     M5C                            = 'Turning/repositioning program'
     M5D                            = 'Nutrition/hydration intrvention'
     M5E                            = 'Ulcer care'
     M5F                            = 'Surgical wound care'
     M5G                            = 'Application of dressings'
     M5H                            = 'Applic of ointments/medications'
     M5I                            = 'Other prevent/protect skin care'
     M5J                            = 'Skin Treatments: None of Above'
     M6A                            = 'Resident has 1+ foot problems'
     M6B                            = 'Infectn foot--e.g., cellulitis'
     M6C                            = 'Open lesions on foot'
     M6D                            = 'Nails/calluses trimmed in last'
     M6E                            = 'Recvd prevent/protect foot care'
     M6F                            = 'Application of dressings (foot)'
     M6G                            = 'Foot Problems/Care: None Above'
     N1A                            = 'Time Awake: Morning'
     N1B                            = 'Time Awake:  Afternoon'
     N1C                            = 'Time Awake: Evening'
     N1D                            = 'Time Awake: None of Above'
     N2                             = 'Ave Time Involved in Activities'
     N3A                            = 'Pref Settng: Own room'
     N3B                            = 'Pref Settng: Day/activity room'
     N3C                            = 'Pref Settng: Inside NH/off unit'
     N3D                            = 'Pref Settng: Outside facility'
     N3E                            = 'Pref Settng: None of Above'
     N4A                            = 'Actvty Pref: Cards/other games'
     N4B                            = 'Actvty Pref: Crafts/arts'
     N4C                            = 'Actvty Pref: Exercise/sports'
     N4D                            = 'Actvty Pref: Music'
     N4E                            = 'Actvty Pref:Reading/writng'
     N4F                            = 'Actvty Pref:Spiritul/relig actv'
     N4G                            = 'Actvty Pref:Trips/shopping'
     N4H                            = 'Actvty Pref:Walk/wheel outdoors'
     N4I                            = 'Actvty Pref:Watching TV'
     N4J                            = 'Actvty Pref:Gardening/plants'
     N4K                            = 'Actvty Pref:Talking/conversing'
     N4L                            = 'Actvty Pref:Helping others'
     N4M                            = 'Actvty Pref:None of Above'
     N5A                            = 'Type of activities involved in'
     N5B                            = 'Extent of involvement in actvty'
     O1                             = 'Number of Medications'
     O2                             = 'New Medications'
     O3                             = 'Injections (number days)'
     O4A                            = 'Antipsychotic: Days received'
     O4B                            = 'Antianxiety: Days received'
     O4C                            = 'Antidepressants: Days received'
     O4D                            = 'Hypnotic: Days received'
     O4E                            = 'Diuretic: Days received'
     P1AA                           = 'Chemotherapy'
     P1AB                           = 'Dialysis'
     P1AC                           = 'IV medication'
     P1AD                           = 'Intake/output'
     P1AE                           = 'Monitoring acute medical condtn'
     P1AF                           = 'Ostomy care'
     P1AG                           = 'Oxygen therapy'
     P1AH                           = 'Radiation'
     P1AI                           = 'Suctioning'
     P1AJ                           = 'Tracheostomy care'
     P1AK                           = 'Transfusions'
     P1AL                           = 'Ventilator or respirator'
     P1AM                           = 'Alcohol/drug treatment program'
     P1AN                           = 'Alzhmrs/demntia spec care unit'
     P1AO                           = 'Hospice care'
     P1AP                           = 'Pediatric unit'
     P1AQ                           = 'Respite care'
     P1AR                           = 'Training in community skills'
     P1AS                           = 'Specl Treatmt/Progms: NoneAbove'
     P1BAA                          = 'Speech therpy: # days'
     P1BAB                          = 'Speech therpy: total # minutes'
     P1BBA                          = 'Occuptnl therpy: # days'
     P1BBB                          = 'Occuptnl therpy: tot # minutes'
     P1BCA                          = 'Physicl therpy: # days'
     P1BCB                          = 'Physicl therpy: total # minut'
     P1BDA                          = 'Resp therpy: # days'
     P1BDB                          = 'Resp therpy: total # minutes'
     P1BEA                          = 'Psych therpy: # days'
     P1BEB                          = 'Psych therpy: total # minutes'
     P2A                            = 'Special behav symptom eval prog'
     P2B                            = 'Evaluation by licensed MH spec'
     P2C                            = 'Group therapy'
     P2D                            = 'Res-specific changes in environ'
     P2E                            = 'Reorientation--e.g, cueing'
     P2F                            = 'Mood/Behavr/CogLossPrgm:NoneAbv'
     P3A                            = 'Nursg Rehab:ROM (passive)'
     P3B                            = 'Nursg Rehab:ROM (active)'
     P3C                            = 'Nursg Rehab:Splint/brace assist'
     P3D                            = 'Nursg Rehab:Bed mobility'
     P3E                            = 'Nursg Rehab:Transfer'
     P3F                            = 'Nursg Rehab:Walking'
     P3G                            = 'Nursg Rehab:Dressing or groomng'
     P3H                            = 'Nursg Rehab:Eating or swallowng'
     P3I                            = 'Nursg Rehab:Amput/prosthes care'
     P3J                            = 'Nursg Rehab:Communication'
     P3K                            = 'Nursg Rehab:Other'
     P4A                            = 'Full bed rails all sides of bed'
     P4B                            = 'Other types of side rails used'
     P4C                            = 'Trunk restraint'
     P4D                            = 'Limb restraint'
     P4E                            = 'Chair prevents rising'
     P5                             = 'Hospital Stays'
     P6                             = 'Emergency Room (ER) Visits'
     P7                             = 'Physician Visits'
     P8                             = 'Physician Orders'
     P9                             = 'Abnormal Lab Values'
     Q1A                            = 'Res wishes to return to comunty'
     Q1B                            = 'Support pers postv tward dischg'
     Q1C                            = 'Stay proj to be short duration'
     Q2                             = 'Overall Change in Care Needs'
     R1A                            = 'Participation in Asses:Residnt'
     R1B                            = 'Participation in Asses:Family'
     R1C                            = 'Participation in Asses:Sig othr'
     R2B                            = 'Date RN Coord Signed Asses'
     R3A                            = 'Primary Code for Res Dschg Disp'
     R3B                            = 'Optnl State Code Res Dschg Disp'
     R4                             = 'Discharge Date'
     S_FILL1                        = 'Filler'
     S_FILL2                        = 'Filler'
     S_FILL3                        = 'Filler'
     T1AA                           = 'Recreation Therapy: # of days'
     T1AB                           = 'Rec Therapy: Total # minutes'
     T1B                            = 'Ordrd Therapies (yes/no)'
     T1C                            = 'Ordrd Thrpies:Est days-day 15'
     T1D                            = 'Ordrd Thrpies: Est min-day 15'
     T2A                            = 'Furthest distance walked'
     T2B                            = 'Time walked w/o sitting down'
     T2C                            = 'Self-performance in walking'
     T2D                            = 'Walking support provided'
     T2E                            = 'Parallel bars used'
     T3MCARE                        = '(T3) Medicare Calculated RUG'
     T3STATE                        = 'State Case Mix Group'
     FILLER                         = 'Filler'
     VA01A                          = 'RAP 1--Delirium:Trig'
     VA01B                          = 'RAP 1--Delirium:Pw/C'
     VA02A                          = 'RAP 2--Cognitive Loss:Trig'
     VA02B                          = 'RAP 2--Cognitive Loss:Pw/C'
     VA03A                          = 'RAP 3--Visual Function:Trig'
     VA03B                          = 'RAP 3--Visual Function:Pw/C'
     VA04A                          = 'RAP 4--Communication:Trig'
     VA04B                          = 'RAP 4--Communication:Pw/C'
     VA05A                          = 'RAP 5--ADL Functionl/Rehab:Trig'
     VA05B                          = 'RAP 5--ADL Functionl/Rehab:Pw/C'
     VA06A                          = 'RAP 6--Urinary Incontnence:Trig'
     VA06B                          = 'RAP 6--Urinary Incontnence:Pw/C'
     VA07A                          = 'RAP 7--Psychosocial:Trig'
     VA07B                          = 'RAP 7--Psychosocial:Pw/C'
     VA08A                          = 'RAP 8--Mood State:Trig'
     VA08B                          = 'RAP 8--Mood State:Pw/C'
     VA09A                          = 'RAP 9--Behavioral Symptoms:Trig'
     VA09B                          = 'RAP 9--Behavioral Symptoms:Pw/C'
     VA10A                          = 'RAP 10--Activities:Trig'
     VA10B                          = 'RAP 10--Activities:Pw/C'
     VA11A                          = 'RAP 11--Falls:Trig'
     VA11B                          = 'RAP 11--Falls:Pw/C'
     VA12A                          = 'RAP 12--Nutritional Status:Trig'
     VA12B                          = 'RAP 12--Nutritional Status:Pw/C'
     VA13A                          = 'RAP 13--Feeding Tubes:Trig'
     VA13B                          = 'RAP 13--Feeding Tubes:Pw/C'
     VA14A                          = 'RAP 14--Dehydr/Fluid Maint:Trig'
     VA14B                          = 'RAP 14--Dehydr/Fluid Maint:Pw/C'
     VA15A                          = 'RAP 15--Dental Care:Trig'
     VA15B                          = 'RAP 15--Dental Care:Pw/C'
     VA16A                          = 'RAP 16--Pressure Ulcers:Trig'
     VA16B                          = 'RAP 16--Pressure Ulcers:Pw/C'
     VA17A                          = 'RAP 17--Psychotropic Drug:Trig'
     VA17B                          = 'RAP 17--Psychotropic Drug:Pw/C'
     VA18A                          = 'RAP 18--Physical Restraint:Trig'
     VA18B                          = 'RAP 18--Physical Restraint:Pw/C'
     VA_FILL                        = 'Filler'
     MDS_ASMT_INT_ID                = 'MDS Assessment Internal ID'
     AST_BEG_VER_DT                 = 'Asses Ver Beg Date (corr rec) ALSO SUBMI'
     AST_END_VER_DT                 = 'Asses Ver End Date (corr rec)'
     VB2_RAP_DT                     = 'RAP Assessment Signature Date'
     VB4_CARE_PLAN_DT               = 'RAP Care Plan Signature Date'
     PRIOR_ID                       = 'Filler'
     TARGET_DATE                    = 'Included after 1/01/02'
     HCFAOTHR                       = 'Filler'
     ST_CODE                        = '2 character postal State ID code'
     FAC_INT_ID                     = 'System internl facility ID code'
     MCR_SET_CODE                   = 'Medicare RUGs CMI set used'
     MCD_SET_CODE                   = 'Medicaid RUGs CMI set used'
     MCR_GP                         = 'Medicare Recomptd CMix Grp'
     MCR_VR                         = 'Medicare Recomptd CMix Version'
     MCR_CMI                        = 'Medicare Recomptd CMix Index'
     MCD_GP                         = 'Medicaid Recomptd CMix Grp'
     MCD_VR                         = 'Medicaid Recomptd CMix Version'
     MCD_CMI                        = 'Medicaid Recomptd CMix Index'
     FILLER2                        = 'Filler'
     DATA_END                       = 'End of Data Term Code(Always %)'
;

RUN;

PROC CONTENTS  DATA= rug520.test520a VARNUM;
RUN; 